package main;

import mold.PBSSpeciesIDsComparator;
import validation.MoveSJISSorter;
import validation.SpeciesSJISSorterComparator;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Scanner;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/*
*  Sample8_LevelAndMovesSearcherクラス
*
*  サンプルのメインクラスです。
*  レベルと技（０～４つ）を打ち込み、条件を満たす種族の一覧を表示します。
*
*  変更履歴
*  2021/05/16 完成
*
*/

public class Sample8_LevelAndMovesSearcher {

	// static変数(CSVファイルから読み込んだ情報をメモリに展開)
	public static List<String[]> levelList = new ArrayList<String[]>();
	public static List<String[]> whiteList = new ArrayList<String[]>();
	public static List<String[]> blackList2 = new ArrayList<String[]>();
	public static List<String[]> blackList3 = new ArrayList<String[]>();

	// static変数（技数保持）
	public static int moveCount = 0;

	public static void main(String[] args) {

		// 種族の一覧を作成
		ArrayList<String> SpeciesListTmp1 = new ArrayList<>();
		PBSSpeciesIDsComparator PBSSpeciesIDsComparatorObj = new PBSSpeciesIDsComparator();
		for (int i = 1; i < 252; i++) {
			SpeciesListTmp1.add(PBSSpeciesIDsComparatorObj.PBSSpeciesIDsObj.SpeciesGet(Integer.toString(i)));
		}

		// 種族の一覧をSJIS順にソート
		SpeciesSJISSorterComparator speciesSJISSorterComparator = new SpeciesSJISSorterComparator();
		Collections.sort(SpeciesListTmp1, speciesSJISSorterComparator);

		// レベルを入力受付
		System.out.println("【入力受付】");
		Scanner scanner = new Scanner(System.in);
		String inputStr;
		String regex = "\\A[-]?[0-9]+\\z";
		Pattern pattrn = Pattern.compile(regex);
		Matcher matcher;
		boolean validFlag = false;
		int level = 0;
		System.out.println("・レベルを半角数字で入力して下さい。");
		inputStr = scanner.nextLine();
		while (!validFlag) {
			matcher = pattrn.matcher(inputStr);
			if (!matcher.find()) {
				System.out.println("・半角数字で再入力して下さい。");
				inputStr = scanner.nextLine();
				continue;
			}
			level = Integer.parseInt(inputStr);
			if (level < 2 || level > 100) {
				System.out.println("・2から100の範囲で再入力して下さい。");
				inputStr = scanner.nextLine();
				continue;
			}
			validFlag = true;
		}

		// 技を入力受付
		MoveSJISSorter moveSJISSorter = new MoveSJISSorter();
		String[] moveList = {null,null,null,null};
		validFlag = false;
		System.out.println("・1つ目の技を全角文字で入力して下さい。");System.out.println("　長音記号のみ半角ハイフンを入力して下さい。入力を終える場合は「終了」と入力して下さい。");
		inputStr = scanner.nextLine();
		while (!validFlag) {
			if (inputStr.equals("終了")) {
				validFlag = true;
				continue;
			}
			inputStr = inputStr.replace("-", "ー");
			if (moveSJISSorter.comparator.getSortOrder(inputStr) == 65535) {
				System.out.println("・存在する技名を全角文字で入力して下さい。");System.out.println("　長音記号のみ半角ハイフンを入力して下さい。入力を終える場合は「終了」と入力して下さい。");
				inputStr = scanner.nextLine();
				continue;
			}
			moveList[moveCount] = inputStr;
			moveCount++;
			if (moveCount < 4) {
				int countDisplay = moveCount + 1;
				System.out.println("・" + countDisplay + "つ目の技を全角文字で入力して下さい。");System.out.println("　長音記号のみ半角ハイフンを入力して下さい。入力を終える場合は「終了」と入力して下さい。");
				inputStr = scanner.nextLine();
				continue;
			}
			validFlag = true;
		}
		scanner.close();

		// CSVファイル読み込み
		readCSV();

		// レベル判定
		ArrayList<String> SpeciesListTmp2 = new ArrayList<>();
		int i = 0;
		int j = 0;
		int diff = 0;
		while (i < SpeciesListTmp1.size()) {
			while (j < levelList.size()) {
				if (i >= SpeciesListTmp1.size()) {
					diff = 65535 - speciesSJISSorterComparator.getSortOrder(levelList.get(j)[0]);
				} else {
					diff = speciesSJISSorterComparator.getSortOrder(SpeciesListTmp1.get(i)) - speciesSJISSorterComparator.getSortOrder(levelList.get(j)[0]);
				}
				if (diff == 0){
					if (level >= Integer.parseInt(levelList.get(j)[1])) {
						SpeciesListTmp2.add(SpeciesListTmp1.get(i));
					}
					j++;
				} else if (diff < 0){
					i++;
				} else {
					j++;
				}
			}
			i++;
		}

		// 技の判定
		ArrayList<String> SpeciesListTmp5 = new ArrayList<>();
		if (moveCount == 0) {
			SpeciesListTmp5 = new ArrayList<>(SpeciesListTmp2);
		} else {

			// 判定準備
			String[] moveListSorted = moveSJISSorter.execute(moveList);
			String[] moveName2;
	    	List<String[]> moveNameList2 = new ArrayList<String[]>();
	    	String[] moveName3;
	    	List<String[]> moveNameList3 = new ArrayList<String[]>();
	    	if (moveCount == 2) {
	    		moveName2 = new String[2];
	    		moveName2[0] = moveListSorted[0];
	    		moveName2[1] = moveListSorted[1];
	    		moveNameList2.add(moveName2);
	    	} else if (moveCount == 3) {
	    		moveName2 = new String[2];
	    		moveName2[0] = moveListSorted[0];
	    		moveName2[1] = moveListSorted[1];
	    		moveNameList2.add(moveName2);
	    		moveName2 = new String[2];
	    		moveName2[0] = moveListSorted[0];
	    		moveName2[1] = moveListSorted[2];
	    		moveNameList2.add(moveName2);
	    		moveName2 = new String[2];
	    		moveName2[0] = moveListSorted[1];
	    		moveName2[1] = moveListSorted[2];
	    		moveNameList2.add(moveName2);
	    		moveName3 = new String[3];
	    		moveName3[0] = moveListSorted[0];
	    		moveName3[1] = moveListSorted[1];
	    		moveName3[2] = moveListSorted[2];
	    		moveNameList3.add(moveName3);
	    	} else if (moveCount == 4) {
	    		moveName2 = new String[2];
	    		moveName2[0] = moveListSorted[0];
	    		moveName2[1] = moveListSorted[1];
	    		moveNameList2.add(moveName2);
	    		moveName2 = new String[2];
	    		moveName2[0] = moveListSorted[0];
	    		moveName2[1] = moveListSorted[2];
	    		moveNameList2.add(moveName2);
	    		moveName2 = new String[2];
	    		moveName2[0] = moveListSorted[0];
	    		moveName2[1] = moveListSorted[3];
	    		moveNameList2.add(moveName2);
	    		moveName2 = new String[2];
	    		moveName2[0] = moveListSorted[1];
	    		moveName2[1] = moveListSorted[2];
	    		moveNameList2.add(moveName2);
	    		moveName2 = new String[2];
	    		moveName2[0] = moveListSorted[1];
	    		moveName2[1] = moveListSorted[3];
	    		moveNameList2.add(moveName2);
	    		moveName2 = new String[2];
	    		moveName2[0] = moveListSorted[2];
	    		moveName2[1] = moveListSorted[3];
	    		moveNameList2.add(moveName2);
	    		moveName3 = new String[3];
	    		moveName3[0] = moveListSorted[0];
	    		moveName3[1] = moveListSorted[1];
	    		moveName3[2] = moveListSorted[2];
	    		moveNameList3.add(moveName3);
	    		moveName3 = new String[3];
	    		moveName3[0] = moveListSorted[0];
	    		moveName3[1] = moveListSorted[1];
	    		moveName3[2] = moveListSorted[3];
	    		moveNameList3.add(moveName3);
	    		moveName3 = new String[3];
	    		moveName3[0] = moveListSorted[0];
	    		moveName3[1] = moveListSorted[2];
	    		moveName3[2] = moveListSorted[3];
	    		moveNameList3.add(moveName3);
	    		moveName3 = new String[3];
	    		moveName3[0] = moveListSorted[1];
	    		moveName3[1] = moveListSorted[2];
	    		moveName3[2] = moveListSorted[3];
	    		moveNameList3.add(moveName3);
	    	}

	    	// ホワイトリスト判定
	    	ArrayList<String> SpeciesListTmp3 = new ArrayList<>();
			i = 0;
			j = 0;
			diff = 0;
			int diff2 = 0;
			int tmpCount = 0;
			while (i < SpeciesListTmp2.size()) {
				while (j < whiteList.size()) {
					if (i >= SpeciesListTmp2.size()) {
						diff = 65535 - speciesSJISSorterComparator.getSortOrder(whiteList.get(j)[0]);
					} else {
						diff = speciesSJISSorterComparator.getSortOrder(SpeciesListTmp2.get(i)) - speciesSJISSorterComparator.getSortOrder(whiteList.get(j)[0]);
					}
					if (diff == 0){
						diff2 = moveSJISSorter.comparator.getSortOrder(moveListSorted[tmpCount]) - moveSJISSorter.comparator.getSortOrder(whiteList.get(j)[1]);
						if (diff2 == 0) {
							if (level >= Integer.parseInt(whiteList.get(j)[2])) {
								tmpCount++;
								if (tmpCount == moveCount) {
									SpeciesListTmp3.add(SpeciesListTmp2.get(i));
									j++;
									i++;
									tmpCount = 0;
								}
							} else {
								j++;
								i++;
								tmpCount = 0;
							}
						} else if (diff2 < 0) {
							j++;
							i++;
							tmpCount = 0;
						} else {
							j++;
						}
					} else if (diff < 0){
						i++;
						tmpCount = 0;
					} else {
						j++;
					}
				}
				i++;
			}

			// ブラックリスト判定（技２つ）
			ArrayList<String> SpeciesListTmp4 = new ArrayList<>();
			if (moveCount < 2) {
				SpeciesListTmp4 = new ArrayList<>(SpeciesListTmp3);
			} else {
				i = 0;
				j = 0;
				int l = 0;
				diff = 0;
				diff2 = 0;
				while (i < SpeciesListTmp3.size()) {
					while (j < blackList2.size()) {
						if (i >= SpeciesListTmp3.size()) {
							diff = 65535 - speciesSJISSorterComparator.getSortOrder(blackList2.get(j)[0]);
						} else {
							diff = speciesSJISSorterComparator.getSortOrder(SpeciesListTmp3.get(i)) - speciesSJISSorterComparator.getSortOrder(blackList2.get(j)[0]);
						}
						if (diff == 0){
							diff2 = moveSJISSorter.comparator.getSortOrder(moveNameList2.get(l)[0]) - moveSJISSorter.comparator.getSortOrder(blackList2.get(j)[1]);
							if (diff2 == 0) {
								diff2 = moveSJISSorter.comparator.getSortOrder(moveNameList2.get(l)[1]) - moveSJISSorter.comparator.getSortOrder(blackList2.get(j)[2]);
							}
							if (diff2 == 0) {
								if (level < Integer.parseInt(blackList2.get(j)[4])) {
									j++;
									i++;
									l = 0;
								} else {
									j++;
									l++;
									if (l >= moveNameList2.size()) {
										SpeciesListTmp4.add(SpeciesListTmp3.get(i));
										i++;
										l = 0;
									}
								}
							} else if (diff2 < 0) {
								l++;
								if (l >= moveNameList2.size()) {
									SpeciesListTmp4.add(SpeciesListTmp3.get(i));
									i++;
									l = 0;
								}
							} else {
								j++;
							}
						} else if (diff < 0){
							SpeciesListTmp4.add(SpeciesListTmp3.get(i));
							i++;
							l = 0;
						} else {
							j++;
						}
					}
					if (i < SpeciesListTmp3.size()) {
						SpeciesListTmp4.add(SpeciesListTmp3.get(i));
						i++;
						l = 0;
					}
				}
			}

			// ブラックリスト判定（技３つ）
			if (moveCount < 3) {
				SpeciesListTmp5 = new ArrayList<>(SpeciesListTmp4);
			} else {
				i = 0;
				j = 0;
				int l = 0;
				diff = 0;
				diff2 = 0;
				while (i < SpeciesListTmp4.size()) {
					while (j < blackList3.size()) {
						if (i >= SpeciesListTmp4.size()) {
							diff = 65535 - speciesSJISSorterComparator.getSortOrder(blackList3.get(j)[0]);
						} else {
							diff = speciesSJISSorterComparator.getSortOrder(SpeciesListTmp4.get(i)) - speciesSJISSorterComparator.getSortOrder(blackList3.get(j)[0]);
						}
						if (diff == 0){
							diff2 = moveSJISSorter.comparator.getSortOrder(moveNameList3.get(l)[0]) - moveSJISSorter.comparator.getSortOrder(blackList3.get(j)[1]);
							if (diff2 == 0) {
								diff2 = moveSJISSorter.comparator.getSortOrder(moveNameList3.get(l)[1]) - moveSJISSorter.comparator.getSortOrder(blackList3.get(j)[2]);
								if (diff2 == 0) {
									diff2 = moveSJISSorter.comparator.getSortOrder(moveNameList3.get(l)[2]) - moveSJISSorter.comparator.getSortOrder(blackList3.get(j)[3]);
								}
							}
							if (diff2 == 0) {
								if (level < Integer.parseInt(blackList3.get(j)[4])) {
									j++;
									i++;
									l = 0;
								} else {
									j++;
									l++;
									if (l >= moveNameList3.size()) {
										SpeciesListTmp5.add(SpeciesListTmp4.get(i));
										i++;
										l = 0;
									}
								}
							} else if (diff2 < 0) {
								l++;
								if (l >= moveNameList3.size()) {
									SpeciesListTmp5.add(SpeciesListTmp4.get(i));
									i++;
									l = 0;
								}
							} else {
								j++;
							}
						} else if (diff < 0){
							SpeciesListTmp5.add(SpeciesListTmp4.get(i));
							i++;
							l = 0;
						} else {
							j++;
						}
					}
					if (i < SpeciesListTmp4.size()) {
						SpeciesListTmp5.add(SpeciesListTmp4.get(i));
						i++;
						l = 0;
					}
				}
			}
		}

		// 種族の一覧を図鑑順にソート
		ArrayList<String> SpeciesListDisplay = new ArrayList<>(SpeciesListTmp5);
		Collections.sort(SpeciesListDisplay, PBSSpeciesIDsComparatorObj);

		// 一覧の表示
		System.out.println("【検索結果】");
		for (String str : SpeciesListDisplay) {
			System.out.println(str);
		}

	}

    /* CSVファイル読み込みメソッド
     *   引数　：無し
	 *   戻り値：無し
	 *   例外　：無し
     */
    public static void readCSV() {

    	// フォルダ定義
    	String dataFolder = "sub_tools" + "\\" + "004_Validation_Check" + "\\" + "Data";

    	// 種族最低レベルCSVファイル読み込み
    	File levelFile = new File(dataFolder + "\\levelLowerLimit.csv");
        if (!levelFile.exists()) {
        	System.out.println("CSVファイル「" + dataFolder + levelFile + "」が存在しないので処理を終了します。");
        	System.exit(1);
        }
        BufferedReader levelBr = null;
        try {
        	levelBr = new BufferedReader(new InputStreamReader(new FileInputStream(levelFile),"SJIS"));
        	String str = levelBr.readLine();
        	if(str == null) {
        		throw new NullPointerException();
        	} else {
        		while(str != null){
        			String[] dataRecord = str.split("\\,", 0);
        			levelList.add(dataRecord);
        			str = levelBr.readLine();
        		}
        	}
        } catch (Exception e) {
        	System.out.println("種族最低レベルCSVファイル読込で異常が発生したので処理を終了します。");
        	System.exit(1);
        } finally {
        	try {
        		levelBr.close();
			} catch (IOException e) {
			}
        }

        // 技を検索しない場合はここで終了
        if (moveCount == 0) {
        	return;
        }

        // ホワイトリストCSVファイル読み込み
    	File whiteFile = new File(dataFolder + "\\moveWhiteList.csv");
        if (!levelFile.exists()) {
        	System.out.println("CSVファイル「" + dataFolder + levelFile + "」が存在しないので処理を終了します。");
        	System.exit(1);
        }
        BufferedReader whiteBr = null;
        try {
        	whiteBr = new BufferedReader(new InputStreamReader(new FileInputStream(whiteFile),"SJIS"));
        	String str = whiteBr.readLine();
        	if(str == null) {
        		throw new NullPointerException();
        	} else {
        		while(str != null){
        			String[] dataRecord = str.split("\\,", 0);
        			whiteList.add(dataRecord);
        			str = whiteBr.readLine();
        		}
        	}
        } catch (Exception e) {
        	System.out.println("ホワイトリストCSVファイル読込で異常が発生したので処理を終了します。");
        	System.exit(1);
        } finally {
        	try {
        		whiteBr.close();
			} catch (IOException e) {
			}
        }

        // ブラックリストCSVファイル読み込み
    	File blackFile = new File(dataFolder + "\\moveBlackList.csv");
        if (!levelFile.exists()) {
        	System.out.println("CSVファイル「" + dataFolder + levelFile + "」が存在しないので処理を終了します。");
        	System.exit(1);
        }
        BufferedReader blackBr = null;
        try {
        	blackBr = new BufferedReader(new InputStreamReader(new FileInputStream(blackFile),"SJIS"));
        	String str = blackBr.readLine();
        	if(str == null) {
        		throw new NullPointerException();
        	} else {
        		while(str != null){
        			String[] dataRecord = str.split("\\,", 0);
        			if (dataRecord[3].equals("")) {
        				blackList2.add(dataRecord);
        			} else {
        				blackList3.add(dataRecord);
        			}
        			str = blackBr.readLine();
        		}
        	}
        } catch (Exception e) {
        	System.out.println("ブラックリストCSVファイル読込で異常が発生したので処理を終了します。");
        	System.exit(1);
        } finally {
        	try {
        		blackBr.close();
			} catch (IOException e) {
			}
        }

        // 終了
        return;
    }

}
