package validation;

import mold.PokeMold;

/*
*  EffortLevelCheckクラス
*
*  努力レベルが実現可能かをチェックするクラスです。
*
*  変更履歴
*  2021/05/15 新規作成
*  2021/07/24 HP努力レベル48以上・攻撃努力レベル0の時にバリデーションOKにする実装が漏れていたので修正
*
*/

public class EffortLevelCheck {

	/* 努力レベルの妥当性をチェックするメソッド　参考（https://seesaawiki.jp/pbs-thread/d/%c5%d8%ce%cf%c3%cd%c4%b4%c0%b0）
	 *   引数　：PokeMoldオブジェクト、ValidationMessageStoreオブジェクト
	 *   戻り値：無し
	 *   例外　：無し
	 */
    public void execute(PokeMold pokeMold, ValidationMessageStore validationMessageStore) {

    	// 努力レベルが0～63であることを確認（想定している使い方をしているならこれは満たす）
    	if (pokeMold.HPEffortLevel < 0 || pokeMold.HPEffortLevel > 63 ||
    		pokeMold.attackEffortLevel < 0 || pokeMold.attackEffortLevel > 63 ||
    		pokeMold.blockEffortLevel < 0 || pokeMold.blockEffortLevel > 63 ||
    		pokeMold.speedEffortLevel < 0 || pokeMold.speedEffortLevel > 63 ||
    		pokeMold.specialEffortLevel < 0 || pokeMold.specialEffortLevel > 63) {
    		validationMessageStore.errorMessagesList.add("・" + pokeMold.speciesName + "について、努力レベルは0～63の範囲で入力して下さい。");
    		return;
    	}

    	// 育成可能な下限の世代を取得する
    	int pokeBreedGen = getPokeBreedGen(pokeMold);

    	// バルキーからの進化条件の考慮（ワーニング）
    	if (setTyrogueCheckFlag(pokeMold, pokeBreedGen)) {

    		// サワムラーのチェック
    		if (pokeMold.speciesName.equals("サワムラー")) {
    			if (pokeMold.attackIndividualValue == pokeMold.blockIndividualValue) {
    				if (pokeMold.attackEffortLevel >= (pokeMold.blockEffortLevel + 2)) {
    				} else if (pokeMold.HPEffortLevel == 63 && pokeMold.attackEffortLevel == 63 && pokeMold.blockEffortLevel == 63 && pokeMold.speedEffortLevel == 63 && pokeMold.specialEffortLevel == 63) {
    				} else {
    					validationMessageStore.warningMessagesList.add("・サワムラーについて、進化条件を満たしつつ入力されたレベル・個体値・努力レベルを実現できるか別途検証して下さい。");
    				}
    			} else {
    				validationMessageStore.warningMessagesList.add("・サワムラーについて、進化条件を満たしつつ入力されたレベル・個体値・努力レベルを実現できるか別途検証して下さい。");
    			}
    		// エビワラーのチェック
    		} else if (pokeMold.speciesName.equals("エビワラー")) {
    			if (pokeMold.attackIndividualValue == pokeMold.blockIndividualValue) {
    				if ((pokeMold.attackEffortLevel + 2) <= pokeMold.blockEffortLevel) {
    				} else if (pokeMold.HPEffortLevel == 63 && pokeMold.attackEffortLevel == 63 && pokeMold.blockEffortLevel == 63 && pokeMold.speedEffortLevel == 63 && pokeMold.specialEffortLevel == 63) {
    				} else {
    					validationMessageStore.warningMessagesList.add("・エビワラーについて、進化条件を満たしつつ入力されたレベル・個体値・努力レベルを実現できるか別途検証して下さい。");
    				}
    			} else {
    				validationMessageStore.warningMessagesList.add("・エビワラーについて、進化条件を満たしつつ入力されたレベル・個体値・努力レベルを実現できるか別途検証して下さい。");
    			}
    		// カポエラーのチェック
    		} else if (pokeMold.speciesName.equals("カポエラー")) {
    			if (pokeMold.attackIndividualValue == pokeMold.blockIndividualValue) {
    			} else {
    				validationMessageStore.warningMessagesList.add("・カポエラーについて、進化条件を満たしつつ入力されたレベル・個体値・努力レベルを実現できるか別途検証して下さい。");
    			}
    		}

    	}

    	// 全努力レベルが同一の場合は無条件でOK（リターン）
    	if (pokeMold.HPEffortLevel == pokeMold.attackEffortLevel &&
    		pokeMold.HPEffortLevel == pokeMold.blockEffortLevel &&
    		pokeMold.HPEffortLevel == pokeMold.speedEffortLevel &&
    		pokeMold.HPEffortLevel == pokeMold.specialEffortLevel) {
    		return;
    	}

    	// 獲得経験値の考慮（ワーニング）
    	if (pokeBreedGen == 2) {
    		if (pokeMold.level < 5) {
    			validationMessageStore.warningMessagesList.add("・" + pokeMold.speciesName + "について、入力されたレベルを満たしつつ努力レベル調整が行うことができるか別途検証して下さい。");
    		}
    	} else {
    		if (pokeMold.level < 12) {
    			validationMessageStore.warningMessagesList.add("・" + pokeMold.speciesName + "について、入力されたレベルを満たしつつ努力レベル調整が行うことができるか別途検証して下さい。");
    		}
    	}

    	//  X-63-63-63-63(X=0～63)はOK（リターン）
    	if (pokeMold.attackEffortLevel == 63 &&
        	pokeMold.blockEffortLevel == 63 &&
        	pokeMold.speedEffortLevel == 63 &&
        	pokeMold.specialEffortLevel == 63) {
        	return;
        }

    	// 63- X-63-63-63(X=0～63)はOK（リターン）
    	if (pokeMold.HPEffortLevel == 63 &&
            pokeMold.blockEffortLevel == 63 &&
            pokeMold.speedEffortLevel == 63 &&
            pokeMold.specialEffortLevel == 63) {
            return;
        }

    	// 63-63- X-63-63(X=21～63)はOK（リターン）、63-63- X-63-63(X=0～20)はNG（エラー・リターン）
    	if (pokeMold.HPEffortLevel == 63 &&
            pokeMold.attackEffortLevel == 63 &&
            pokeMold.speedEffortLevel == 63 &&
            pokeMold.specialEffortLevel == 63) {
    		if (pokeMold.blockEffortLevel >= 21) {
    			return;
    		} else {
    			validationMessageStore.errorMessagesList.add("・" + pokeMold.speciesName + "について、他の努力レベルを63にしつつ防御努力レベルを落とす場合、防御努力レベルは21以上にして下さい。");
    			return;
    		}
        }

    	// 63-63-63- X-63(X=0～63)はOK（リターン）
    	if (pokeMold.HPEffortLevel == 63 &&
            pokeMold.attackEffortLevel == 63 &&
            pokeMold.blockEffortLevel == 63 &&
            pokeMold.specialEffortLevel == 63) {
            return;
        }

    	// 63-63-63-63- X(X=22～63)はOK（リターン）、63-63-63-63- X(X=0～21)はNG（エラー・リターン）
    	if (pokeMold.HPEffortLevel == 63 &&
            pokeMold.attackEffortLevel == 63 &&
            pokeMold.blockEffortLevel == 63 &&
            pokeMold.speedEffortLevel == 63) {
        	if (pokeMold.specialEffortLevel >= 22) {
        		return;
        	} else {
        		validationMessageStore.errorMessagesList.add("・" + pokeMold.speciesName + "について、他の努力レベルを63にしつつ特殊努力レベルを落とす場合、特殊努力レベルは21以上にして下さい。");
        		return;
        	}
        }

    	//  X- 0-63-63-63(X=48～63)はOK（リターン）、 X- 0-63-63-63(X=0～47)はNG（エラー・リターン）
    	if (pokeMold.attackEffortLevel == 0 &&
            pokeMold.blockEffortLevel == 63 &&
            pokeMold.speedEffortLevel == 63 &&
            pokeMold.specialEffortLevel == 63) {
            if (pokeMold.HPEffortLevel >= 48) {
            	return;
            } else {
            	validationMessageStore.errorMessagesList.add("・" + pokeMold.speciesName + "について、攻撃努力レベルを0にしつつHP努力レベルを落とす場合、HP努力レベルは48以上にして下さい。");
            	return;
            }
        }

    	//  X- Y-63-63-63(X=25～63、Y=22～63)はOK（リターン）
    	if (pokeMold.HPEffortLevel >= 25 &&
            pokeMold.attackEffortLevel >= 22 &&
            pokeMold.blockEffortLevel == 63 &&
            pokeMold.speedEffortLevel == 63 &&
            pokeMold.specialEffortLevel == 63) {
            return;
        }

    	//  X-63- Y-63-63(X=30～63、Y=21～63)はOK（リターン）
    	if (pokeMold.HPEffortLevel >= 25 &&
            pokeMold.attackEffortLevel >= 22 &&
            pokeMold.blockEffortLevel == 63 &&
            pokeMold.speedEffortLevel == 63 &&
            pokeMold.specialEffortLevel == 63) {
            return;
        }

    	// 第一世代育成不可かつ X-63-63- Y-63（X=33～63、Y=33～63）はOK（リターン）
    	// 第一世代育成可かつ X-63-63- Y-63（X=32～63、Y=32～63）はOK（リターン）
    	if (pokeBreedGen == 2) {
        	if (pokeMold.HPEffortLevel >= 33 &&
                pokeMold.attackEffortLevel == 63 &&
                pokeMold.blockEffortLevel == 63 &&
                pokeMold.speedEffortLevel >= 33 &&
                pokeMold.specialEffortLevel == 63) {
                return;
            }
    	} else {
        	if (pokeMold.HPEffortLevel >= 32 &&
                pokeMold.attackEffortLevel == 63 &&
                pokeMold.blockEffortLevel == 63 &&
                pokeMold.speedEffortLevel >= 32 &&
                pokeMold.specialEffortLevel == 63) {
                return;
            }
    	}

    	//  X-63-63-63- Y(X=41～63、Y=22～63)はOK（リターン）
    	if (pokeMold.HPEffortLevel >= 41 &&
            pokeMold.attackEffortLevel == 63 &&
            pokeMold.blockEffortLevel == 63 &&
            pokeMold.speedEffortLevel == 63 &&
            pokeMold.specialEffortLevel >= 22) {
            return;
        }

    	//  X-63-63-63- Y(X=32～63、Y=23～63)はOK（リターン）
    	if (pokeMold.HPEffortLevel >= 32 &&
            pokeMold.attackEffortLevel == 63 &&
            pokeMold.blockEffortLevel == 63 &&
            pokeMold.speedEffortLevel == 63 &&
            pokeMold.specialEffortLevel >= 23) {
            return;
        }

    	//  X-63-63-63- Y(X=30～63、Y=24～63)はOK（リターン）
    	if (pokeMold.HPEffortLevel >= 30 &&
            pokeMold.attackEffortLevel == 63 &&
            pokeMold.blockEffortLevel == 63 &&
            pokeMold.speedEffortLevel == 63 &&
            pokeMold.specialEffortLevel >= 24) {
            return;
        }

    	// 第一世代育成不可かつ63- X-63- Y-63(X=0～63、Y=39～63)はOK（リターン）
    	// 第一世代育成可かつ63- X-63- Y-63(X=0～63、Y=33～63)はOK（リターン）
    	if (pokeBreedGen == 2) {
        	if (pokeMold.HPEffortLevel == 63 &&
                pokeMold.blockEffortLevel == 63 &&
                pokeMold.speedEffortLevel >= 39 &&
                pokeMold.specialEffortLevel == 63) {
                return;
            }
    	} else {
        	if (pokeMold.HPEffortLevel == 63 &&
                pokeMold.blockEffortLevel == 63 &&
                pokeMold.speedEffortLevel >= 33 &&
                pokeMold.specialEffortLevel == 63) {
                return;
            }
    	}

    	// 63- 0-63-63- X(X=16～63)はOK（リターン）、63- 0-63-63- X(X=0～15)はNG（エラー・リターン）
    	if (pokeMold.HPEffortLevel == 63 &&
            pokeMold.attackEffortLevel == 0 &&
            pokeMold.blockEffortLevel == 63 &&
            pokeMold.speedEffortLevel == 63) {
            if (pokeMold.specialEffortLevel >= 16) {
            	return;
            } else {
            	validationMessageStore.errorMessagesList.add("・" + pokeMold.speciesName + "について、攻撃努力レベルを0にしつつ特殊努力レベルを落とす場合、特殊努力レベルは16以上にして下さい。");
            	return;
            }
        }

    	// 63-63- X- Y-63(X=28～63、Y=28～63)はOK（リターン）
    	if (pokeMold.HPEffortLevel == 63 &&
            pokeMold.attackEffortLevel == 63 &&
            pokeMold.blockEffortLevel >= 28 &&
            pokeMold.speedEffortLevel >= 28 &&
            pokeMold.specialEffortLevel == 63) {
            return;
        }

    	// 63-63- X-63- Y(X=22～63、Y=45～63)はOK（リターン）
    	if (pokeMold.HPEffortLevel == 63 &&
            pokeMold.attackEffortLevel == 63 &&
            pokeMold.blockEffortLevel >= 22 &&
            pokeMold.speedEffortLevel == 63 &&
            pokeMold.specialEffortLevel >= 45) {
            return;
        }

    	// 第一世代育成不可かつ63- 0- X- Y-63(X=0～63、Y=39～63)はOK（リターン）、63- 0- X- Y-63(X=0～63、Y=0～38)はNG（エラー・リターン）
    	// 第一世代育成可かつ63- 0- X- Y-63(X=0～63、Y=33～63)はOK（リターン）、63- 0- X- Y-63(X=0～63、Y=0～32)はNG（エラー・リターン）
    	if (pokeBreedGen == 2) {
        	if (pokeMold.HPEffortLevel == 63 &&
                pokeMold.attackEffortLevel == 0 &&
                pokeMold.speedEffortLevel >= 39 &&
                pokeMold.specialEffortLevel == 63) {
                return;
            } else if (pokeMold.HPEffortLevel == 63 &&
                        pokeMold.attackEffortLevel == 0 &&
                        pokeMold.speedEffortLevel <= 38 &&
                        pokeMold.specialEffortLevel == 63) {
            	validationMessageStore.errorMessagesList.add("・" + pokeMold.speciesName + "について、攻撃努力レベルを0にしつつ素早さ努力レベルを落とす場合、素早さ努力レベルは39以上にして下さい。");
    			return;
            }
    	} else {
    		if (pokeMold.HPEffortLevel == 63 &&
                pokeMold.attackEffortLevel == 0 &&
                pokeMold.speedEffortLevel >= 33 &&
                pokeMold.specialEffortLevel == 63) {
                return;
            } else if (pokeMold.HPEffortLevel == 63 &&
                        pokeMold.attackEffortLevel == 0 &&
                        pokeMold.speedEffortLevel <= 32 &&
                        pokeMold.specialEffortLevel == 63) {
                validationMessageStore.errorMessagesList.add("・" + pokeMold.speciesName + "について、攻撃努力レベルを0にしつつ素早さ努力レベルを落とす場合、素早さ努力レベルは39以上にして下さい。");
        		return;
            }
    	}

    	// 62- 0- X-20-17(X=15～63)はOK（リターン）
    	if (pokeMold.HPEffortLevel == 62 &&
            pokeMold.attackEffortLevel == 0 &&
            pokeMold.blockEffortLevel >= 15 &&
            pokeMold.speedEffortLevel == 20 &&
            pokeMold.specialEffortLevel == 17) {
            return;
        }

    	// 上記以外は全てワーニング・リターン
    	validationMessageStore.warningMessagesList.add("・" + pokeMold.speciesName + "は特殊な努力レベル調整が行われています。実現可能か別途検証して下さい。");
    	return;

    }

	/* 育成可能な下限の世代を取得するメソッド
	 *   引数　：PokeMoldオブジェクト
	 *   戻り値：世代（int）
	 *   例外　：無し
	 */
    public int getPokeBreedGen(PokeMold pokeMold) {

    	// 無条件で第一世代で育成できない種族の一覧
    	if (pokeMold.speciesName.equals("チコリータ")) { return 2; }
    	if (pokeMold.speciesName.equals("ベイリーフ")) { return 2; }
    	if (pokeMold.speciesName.equals("メガニウム")) { return 2; }
    	if (pokeMold.speciesName.equals("ヒノアラシ")) { return 2; }
    	if (pokeMold.speciesName.equals("マグマラシ")) { return 2; }
    	if (pokeMold.speciesName.equals("バクフーン")) { return 2; }
    	if (pokeMold.speciesName.equals("ワニノコ")) { return 2; }
    	if (pokeMold.speciesName.equals("アリゲイツ")) { return 2; }
    	if (pokeMold.speciesName.equals("オーダイル")) { return 2; }
    	if (pokeMold.speciesName.equals("オタチ")) { return 2; }
    	if (pokeMold.speciesName.equals("オオタチ")) { return 2; }
    	if (pokeMold.speciesName.equals("ホーホー")) { return 2; }
    	if (pokeMold.speciesName.equals("ヨルノズク")) { return 2; }
    	if (pokeMold.speciesName.equals("レディバ")) { return 2; }
    	if (pokeMold.speciesName.equals("レディアン")) { return 2; }
    	if (pokeMold.speciesName.equals("イトマル")) { return 2; }
    	if (pokeMold.speciesName.equals("アリアドス")) { return 2; }
    	if (pokeMold.speciesName.equals("チョンチー")) { return 2; }
    	if (pokeMold.speciesName.equals("ランターン")) { return 2; }
    	if (pokeMold.speciesName.equals("ピチュー")) { return 2; }
    	if (pokeMold.speciesName.equals("ピィ")) { return 2; }
    	if (pokeMold.speciesName.equals("ププリン")) { return 2; }
    	if (pokeMold.speciesName.equals("トゲピー")) { return 2; }
    	if (pokeMold.speciesName.equals("トゲチック")) { return 2; }
    	if (pokeMold.speciesName.equals("ネイティ")) { return 2; }
    	if (pokeMold.speciesName.equals("ネイティオ")) { return 2; }
    	if (pokeMold.speciesName.equals("メリープ")) { return 2; }
    	if (pokeMold.speciesName.equals("モココ")) { return 2; }
    	if (pokeMold.speciesName.equals("デンリュウ")) { return 2; }
    	if (pokeMold.speciesName.equals("マリル")) { return 2; }
    	if (pokeMold.speciesName.equals("マリルリ")) { return 2; }
    	if (pokeMold.speciesName.equals("ウソッキー")) { return 2; }
    	if (pokeMold.speciesName.equals("ハネッコ")) { return 2; }
    	if (pokeMold.speciesName.equals("ポポッコ")) { return 2; }
    	if (pokeMold.speciesName.equals("ワタッコ")) { return 2; }
    	if (pokeMold.speciesName.equals("エイパム")) { return 2; }
    	if (pokeMold.speciesName.equals("ヒマナッツ")) { return 2; }
    	if (pokeMold.speciesName.equals("キマワリ")) { return 2; }
    	if (pokeMold.speciesName.equals("ヤンヤンマ")) { return 2; }
    	if (pokeMold.speciesName.equals("ウパー")) { return 2; }
    	if (pokeMold.speciesName.equals("ヌオー")) { return 2; }
    	if (pokeMold.speciesName.equals("ヤミカラス")) { return 2; }
    	if (pokeMold.speciesName.equals("ムウマ")) { return 2; }
    	if (pokeMold.speciesName.equals("アンノーン")) { return 2; }
    	if (pokeMold.speciesName.equals("ソーナンス")) { return 2; }
    	if (pokeMold.speciesName.equals("キリンリキ")) { return 2; }
    	if (pokeMold.speciesName.equals("クヌギダマ")) { return 2; }
    	if (pokeMold.speciesName.equals("フォレトス")) { return 2; }
    	if (pokeMold.speciesName.equals("ノコッチ")) { return 2; }
    	if (pokeMold.speciesName.equals("グライガー")) { return 2; }
    	if (pokeMold.speciesName.equals("ブルー")) { return 2; }
    	if (pokeMold.speciesName.equals("グランブル")) { return 2; }
    	if (pokeMold.speciesName.equals("ハリーセン")) { return 2; }
    	if (pokeMold.speciesName.equals("ツボツボ")) { return 2; }
    	if (pokeMold.speciesName.equals("ヘラクロス")) { return 2; }
    	if (pokeMold.speciesName.equals("ニューラ")) { return 2; }
    	if (pokeMold.speciesName.equals("ヒメグマ")) { return 2; }
    	if (pokeMold.speciesName.equals("リングマ")) { return 2; }
    	if (pokeMold.speciesName.equals("マグマッグ")) { return 2; }
    	if (pokeMold.speciesName.equals("マグカルゴ")) { return 2; }
    	if (pokeMold.speciesName.equals("ウリムー")) { return 2; }
    	if (pokeMold.speciesName.equals("イノムー")) { return 2; }
    	if (pokeMold.speciesName.equals("サニーゴ")) { return 2; }
    	if (pokeMold.speciesName.equals("テッポウオ")) { return 2; }
    	if (pokeMold.speciesName.equals("オクタン")) { return 2; }
    	if (pokeMold.speciesName.equals("デリバード")) { return 2; }
    	if (pokeMold.speciesName.equals("マンタイン")) { return 2; }
    	if (pokeMold.speciesName.equals("エアームド")) { return 2; }
    	if (pokeMold.speciesName.equals("デルビル")) { return 2; }
    	if (pokeMold.speciesName.equals("ヘルガー")) { return 2; }
    	if (pokeMold.speciesName.equals("ゴマゾウ")) { return 2; }
    	if (pokeMold.speciesName.equals("ドンファン")) { return 2; }
    	if (pokeMold.speciesName.equals("オドシシ")) { return 2; }
    	if (pokeMold.speciesName.equals("ドーブル")) { return 2; }
    	if (pokeMold.speciesName.equals("バルキー")) { return 2; }
    	if (pokeMold.speciesName.equals("カポエラー")) { return 2; }
    	if (pokeMold.speciesName.equals("ムチュール")) { return 2; }
    	if (pokeMold.speciesName.equals("エレキッド")) { return 2; }
    	if (pokeMold.speciesName.equals("ブビィ")) { return 2; }
    	if (pokeMold.speciesName.equals("ミルタンク")) { return 2; }
    	if (pokeMold.speciesName.equals("ライコウ")) { return 2; }
    	if (pokeMold.speciesName.equals("エンテイ")) { return 2; }
    	if (pokeMold.speciesName.equals("スイクン")) { return 2; }
    	if (pokeMold.speciesName.equals("ヨーギラス")) { return 2; }
    	if (pokeMold.speciesName.equals("サナギラス")) { return 2; }
    	if (pokeMold.speciesName.equals("バンギラス")) { return 2; }
    	if (pokeMold.speciesName.equals("ルギア")) { return 2; }
    	if (pokeMold.speciesName.equals("ホウオウ")) { return 2; }
    	if (pokeMold.speciesName.equals("セレビィ")) { return 2; }

    	// 特定の技を覚えさせたい場合に第一世代で育成できないポケモンの一覧
    	if (pokeMold.speciesName.equals("フシギダネ") && (pokeMold.moveName[0].equals("げんしのちから") || pokeMold.moveName[1].equals("げんしのちから") || pokeMold.moveName[2].equals("げんしのちから") || pokeMold.moveName[3].equals("げんしのちから"))) { return 2; }
    	if (pokeMold.speciesName.equals("フシギダネ") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("フシギソウ") && (pokeMold.moveName[0].equals("げんしのちから") || pokeMold.moveName[1].equals("げんしのちから") || pokeMold.moveName[2].equals("げんしのちから") || pokeMold.moveName[3].equals("げんしのちから"))) { return 2; }
    	if (pokeMold.speciesName.equals("フシギソウ") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("フシギバナ") && (pokeMold.moveName[0].equals("げんしのちから") || pokeMold.moveName[1].equals("げんしのちから") || pokeMold.moveName[2].equals("げんしのちから") || pokeMold.moveName[3].equals("げんしのちから"))) { return 2; }
    	if (pokeMold.speciesName.equals("フシギバナ") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヒトカゲ") && (pokeMold.moveName[0].equals("かみくだく") || pokeMold.moveName[1].equals("かみくだく") || pokeMold.moveName[2].equals("かみくだく") || pokeMold.moveName[3].equals("かみくだく"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヒトカゲ") && (pokeMold.moveName[0].equals("げきりん") || pokeMold.moveName[1].equals("げきりん") || pokeMold.moveName[2].equals("げきりん") || pokeMold.moveName[3].equals("げきりん"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヒトカゲ") && (pokeMold.moveName[0].equals("げんしのちから") || pokeMold.moveName[1].equals("げんしのちから") || pokeMold.moveName[2].equals("げんしのちから") || pokeMold.moveName[3].equals("げんしのちから"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヒトカゲ") && (pokeMold.moveName[0].equals("はらだいこ") || pokeMold.moveName[1].equals("はらだいこ") || pokeMold.moveName[2].equals("はらだいこ") || pokeMold.moveName[3].equals("はらだいこ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヒトカゲ") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("リザード") && (pokeMold.moveName[0].equals("かみくだく") || pokeMold.moveName[1].equals("かみくだく") || pokeMold.moveName[2].equals("かみくだく") || pokeMold.moveName[3].equals("かみくだく"))) { return 2; }
    	if (pokeMold.speciesName.equals("リザード") && (pokeMold.moveName[0].equals("げきりん") || pokeMold.moveName[1].equals("げきりん") || pokeMold.moveName[2].equals("げきりん") || pokeMold.moveName[3].equals("げきりん"))) { return 2; }
    	if (pokeMold.speciesName.equals("リザード") && (pokeMold.moveName[0].equals("げんしのちから") || pokeMold.moveName[1].equals("げんしのちから") || pokeMold.moveName[2].equals("げんしのちから") || pokeMold.moveName[3].equals("げんしのちから"))) { return 2; }
    	if (pokeMold.speciesName.equals("リザード") && (pokeMold.moveName[0].equals("はらだいこ") || pokeMold.moveName[1].equals("はらだいこ") || pokeMold.moveName[2].equals("はらだいこ") || pokeMold.moveName[3].equals("はらだいこ"))) { return 2; }
    	if (pokeMold.speciesName.equals("リザード") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("リザードン") && (pokeMold.moveName[0].equals("かみくだく") || pokeMold.moveName[1].equals("かみくだく") || pokeMold.moveName[2].equals("かみくだく") || pokeMold.moveName[3].equals("かみくだく"))) { return 2; }
    	if (pokeMold.speciesName.equals("リザードン") && (pokeMold.moveName[0].equals("げきりん") || pokeMold.moveName[1].equals("げきりん") || pokeMold.moveName[2].equals("げきりん") || pokeMold.moveName[3].equals("げきりん"))) { return 2; }
    	if (pokeMold.speciesName.equals("リザードン") && (pokeMold.moveName[0].equals("げんしのちから") || pokeMold.moveName[1].equals("げんしのちから") || pokeMold.moveName[2].equals("げんしのちから") || pokeMold.moveName[3].equals("げんしのちから"))) { return 2; }
    	if (pokeMold.speciesName.equals("リザードン") && (pokeMold.moveName[0].equals("はらだいこ") || pokeMold.moveName[1].equals("はらだいこ") || pokeMold.moveName[2].equals("はらだいこ") || pokeMold.moveName[3].equals("はらだいこ"))) { return 2; }
    	if (pokeMold.speciesName.equals("リザードン") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("ゼニガメ") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ゼニガメ") && (pokeMold.moveName[0].equals("みやぶる") || pokeMold.moveName[1].equals("みやぶる") || pokeMold.moveName[2].equals("みやぶる") || pokeMold.moveName[3].equals("みやぶる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ゼニガメ") && (pokeMold.moveName[0].equals("ミラーコート") || pokeMold.moveName[1].equals("ミラーコート") || pokeMold.moveName[2].equals("ミラーコート") || pokeMold.moveName[3].equals("ミラーコート"))) { return 2; }
    	if (pokeMold.speciesName.equals("カメール") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("カメール") && (pokeMold.moveName[0].equals("みやぶる") || pokeMold.moveName[1].equals("みやぶる") || pokeMold.moveName[2].equals("みやぶる") || pokeMold.moveName[3].equals("みやぶる"))) { return 2; }
    	if (pokeMold.speciesName.equals("カメール") && (pokeMold.moveName[0].equals("ミラーコート") || pokeMold.moveName[1].equals("ミラーコート") || pokeMold.moveName[2].equals("ミラーコート") || pokeMold.moveName[3].equals("ミラーコート"))) { return 2; }
    	if (pokeMold.speciesName.equals("カメックス") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("カメックス") && (pokeMold.moveName[0].equals("みやぶる") || pokeMold.moveName[1].equals("みやぶる") || pokeMold.moveName[2].equals("みやぶる") || pokeMold.moveName[3].equals("みやぶる"))) { return 2; }
    	if (pokeMold.speciesName.equals("カメックス") && (pokeMold.moveName[0].equals("ミラーコート") || pokeMold.moveName[1].equals("ミラーコート") || pokeMold.moveName[2].equals("ミラーコート") || pokeMold.moveName[3].equals("ミラーコート"))) { return 2; }
    	if (pokeMold.speciesName.equals("ポッポ") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ポッポ") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ポッポ") && (pokeMold.moveName[0].equals("みやぶる") || pokeMold.moveName[1].equals("みやぶる") || pokeMold.moveName[2].equals("みやぶる") || pokeMold.moveName[3].equals("みやぶる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピジョン") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピジョン") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピジョン") && (pokeMold.moveName[0].equals("みやぶる") || pokeMold.moveName[1].equals("みやぶる") || pokeMold.moveName[2].equals("みやぶる") || pokeMold.moveName[3].equals("みやぶる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピジョット") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピジョット") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピジョット") && (pokeMold.moveName[0].equals("みやぶる") || pokeMold.moveName[1].equals("みやぶる") || pokeMold.moveName[2].equals("みやぶる") || pokeMold.moveName[3].equals("みやぶる"))) { return 2; }
    	if (pokeMold.speciesName.equals("コラッタ") && (pokeMold.moveName[0].equals("かえんぐるま") || pokeMold.moveName[1].equals("かえんぐるま") || pokeMold.moveName[2].equals("かえんぐるま") || pokeMold.moveName[3].equals("かえんぐるま"))) { return 2; }
    	if (pokeMold.speciesName.equals("コラッタ") && (pokeMold.moveName[0].equals("きしかいせい") || pokeMold.moveName[1].equals("きしかいせい") || pokeMold.moveName[2].equals("きしかいせい") || pokeMold.moveName[3].equals("きしかいせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("ラッタ") && (pokeMold.moveName[0].equals("かえんぐるま") || pokeMold.moveName[1].equals("かえんぐるま") || pokeMold.moveName[2].equals("かえんぐるま") || pokeMold.moveName[3].equals("かえんぐるま"))) { return 2; }
    	if (pokeMold.speciesName.equals("ラッタ") && (pokeMold.moveName[0].equals("きしかいせい") || pokeMold.moveName[1].equals("きしかいせい") || pokeMold.moveName[2].equals("きしかいせい") || pokeMold.moveName[3].equals("きしかいせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("オニスズメ") && (pokeMold.moveName[0].equals("こわいかお") || pokeMold.moveName[1].equals("こわいかお") || pokeMold.moveName[2].equals("こわいかお") || pokeMold.moveName[3].equals("こわいかお"))) { return 2; }
    	if (pokeMold.speciesName.equals("オニスズメ") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("オニスズメ") && (pokeMold.moveName[0].equals("みねうち") || pokeMold.moveName[1].equals("みねうち") || pokeMold.moveName[2].equals("みねうち") || pokeMold.moveName[3].equals("みねうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("オニドリル") && (pokeMold.moveName[0].equals("こわいかお") || pokeMold.moveName[1].equals("こわいかお") || pokeMold.moveName[2].equals("こわいかお") || pokeMold.moveName[3].equals("こわいかお"))) { return 2; }
    	if (pokeMold.speciesName.equals("オニドリル") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("オニドリル") && (pokeMold.moveName[0].equals("みねうち") || pokeMold.moveName[1].equals("みねうち") || pokeMold.moveName[2].equals("みねうち") || pokeMold.moveName[3].equals("みねうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("アーボ") && (pokeMold.moveName[0].equals("うらみ") || pokeMold.moveName[1].equals("うらみ") || pokeMold.moveName[2].equals("うらみ") || pokeMold.moveName[3].equals("うらみ"))) { return 2; }
    	if (pokeMold.speciesName.equals("アーボ") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("アーボ") && (pokeMold.moveName[0].equals("かみくだく") || pokeMold.moveName[1].equals("かみくだく") || pokeMold.moveName[2].equals("かみくだく") || pokeMold.moveName[3].equals("かみくだく"))) { return 2; }
    	if (pokeMold.speciesName.equals("アーボ") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("アーボック") && (pokeMold.moveName[0].equals("うらみ") || pokeMold.moveName[1].equals("うらみ") || pokeMold.moveName[2].equals("うらみ") || pokeMold.moveName[3].equals("うらみ"))) { return 2; }
    	if (pokeMold.speciesName.equals("アーボック") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("アーボック") && (pokeMold.moveName[0].equals("かみくだく") || pokeMold.moveName[1].equals("かみくだく") || pokeMold.moveName[2].equals("かみくだく") || pokeMold.moveName[3].equals("かみくだく"))) { return 2; }
    	if (pokeMold.speciesName.equals("アーボック") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピカチュウ") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピカチュウ") && (pokeMold.moveName[0].equals("きしかいせい") || pokeMold.moveName[1].equals("きしかいせい") || pokeMold.moveName[2].equals("きしかいせい") || pokeMold.moveName[3].equals("きしかいせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピカチュウ") && (pokeMold.moveName[0].equals("てんしのキッス") || pokeMold.moveName[1].equals("てんしのキッス") || pokeMold.moveName[2].equals("てんしのキッス") || pokeMold.moveName[3].equals("てんしのキッス"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピカチュウ") && (pokeMold.moveName[0].equals("アンコール") || pokeMold.moveName[1].equals("アンコール") || pokeMold.moveName[2].equals("アンコール") || pokeMold.moveName[3].equals("アンコール"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピカチュウ") && (pokeMold.moveName[0].equals("プレゼント") || pokeMold.moveName[1].equals("プレゼント") || pokeMold.moveName[2].equals("プレゼント") || pokeMold.moveName[3].equals("プレゼント"))) { return 2; }
    	if (pokeMold.speciesName.equals("ライチュウ") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ライチュウ") && (pokeMold.moveName[0].equals("きしかいせい") || pokeMold.moveName[1].equals("きしかいせい") || pokeMold.moveName[2].equals("きしかいせい") || pokeMold.moveName[3].equals("きしかいせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("ライチュウ") && (pokeMold.moveName[0].equals("てんしのキッス") || pokeMold.moveName[1].equals("てんしのキッス") || pokeMold.moveName[2].equals("てんしのキッス") || pokeMold.moveName[3].equals("てんしのキッス"))) { return 2; }
    	if (pokeMold.speciesName.equals("ライチュウ") && (pokeMold.moveName[0].equals("アンコール") || pokeMold.moveName[1].equals("アンコール") || pokeMold.moveName[2].equals("アンコール") || pokeMold.moveName[3].equals("アンコール"))) { return 2; }
    	if (pokeMold.speciesName.equals("ライチュウ") && (pokeMold.moveName[0].equals("プレゼント") || pokeMold.moveName[1].equals("プレゼント") || pokeMold.moveName[2].equals("プレゼント") || pokeMold.moveName[3].equals("プレゼント"))) { return 2; }
    	if (pokeMold.speciesName.equals("サンド") && (pokeMold.moveName[0].equals("こうそくスピン") || pokeMold.moveName[1].equals("こうそくスピン") || pokeMold.moveName[2].equals("こうそくスピン") || pokeMold.moveName[3].equals("こうそくスピン"))) { return 2; }
    	if (pokeMold.speciesName.equals("サンド") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("サンド") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("サンド") && (pokeMold.moveName[0].equals("メタルクロー") || pokeMold.moveName[1].equals("メタルクロー") || pokeMold.moveName[2].equals("メタルクロー") || pokeMold.moveName[3].equals("メタルクロー"))) { return 2; }
    	if (pokeMold.speciesName.equals("サンドパン") && (pokeMold.moveName[0].equals("こうそくスピン") || pokeMold.moveName[1].equals("こうそくスピン") || pokeMold.moveName[2].equals("こうそくスピン") || pokeMold.moveName[3].equals("こうそくスピン"))) { return 2; }
    	if (pokeMold.speciesName.equals("サンドパン") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("サンドパン") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("サンドパン") && (pokeMold.moveName[0].equals("メタルクロー") || pokeMold.moveName[1].equals("メタルクロー") || pokeMold.moveName[2].equals("メタルクロー") || pokeMold.moveName[3].equals("メタルクロー"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニドラン♀") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニドラン♀") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニドリーナ") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニドリーナ") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニドクイン") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニドクイン") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニドラン♂") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニドリーノ") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニドキング") && (pokeMold.moveName[0].equals("ふくろただき") || pokeMold.moveName[1].equals("ふくろただき") || pokeMold.moveName[2].equals("ふくろただき") || pokeMold.moveName[3].equals("ふくろただき"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピッピ") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピッピ") && (pokeMold.moveName[0].equals("てんしのキッス") || pokeMold.moveName[1].equals("てんしのキッス") || pokeMold.moveName[2].equals("てんしのキッス") || pokeMold.moveName[3].equals("てんしのキッス"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピッピ") && (pokeMold.moveName[0].equals("はらだいこ") || pokeMold.moveName[1].equals("はらだいこ") || pokeMold.moveName[2].equals("はらだいこ") || pokeMold.moveName[3].equals("はらだいこ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピッピ") && (pokeMold.moveName[0].equals("プレゼント") || pokeMold.moveName[1].equals("プレゼント") || pokeMold.moveName[2].equals("プレゼント") || pokeMold.moveName[3].equals("プレゼント"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピクシー") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピクシー") && (pokeMold.moveName[0].equals("てんしのキッス") || pokeMold.moveName[1].equals("てんしのキッス") || pokeMold.moveName[2].equals("てんしのキッス") || pokeMold.moveName[3].equals("てんしのキッス"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピクシー") && (pokeMold.moveName[0].equals("はらだいこ") || pokeMold.moveName[1].equals("はらだいこ") || pokeMold.moveName[2].equals("はらだいこ") || pokeMold.moveName[3].equals("はらだいこ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ピクシー") && (pokeMold.moveName[0].equals("プレゼント") || pokeMold.moveName[1].equals("プレゼント") || pokeMold.moveName[2].equals("プレゼント") || pokeMold.moveName[3].equals("プレゼント"))) { return 2; }
    	if (pokeMold.speciesName.equals("ロコン") && (pokeMold.moveName[0].equals("うらみ") || pokeMold.moveName[1].equals("うらみ") || pokeMold.moveName[2].equals("うらみ") || pokeMold.moveName[3].equals("うらみ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ロコン") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ロコン") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("キュウコン") && (pokeMold.moveName[0].equals("うらみ") || pokeMold.moveName[1].equals("うらみ") || pokeMold.moveName[2].equals("うらみ") || pokeMold.moveName[3].equals("うらみ"))) { return 2; }
    	if (pokeMold.speciesName.equals("キュウコン") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("キュウコン") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("プリン") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("プリン") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("プリン") && (pokeMold.moveName[0].equals("てんしのキッス") || pokeMold.moveName[1].equals("てんしのキッス") || pokeMold.moveName[2].equals("てんしのキッス") || pokeMold.moveName[3].equals("てんしのキッス"))) { return 2; }
    	if (pokeMold.speciesName.equals("プリン") && (pokeMold.moveName[0].equals("ほろびのうた") || pokeMold.moveName[1].equals("ほろびのうた") || pokeMold.moveName[2].equals("ほろびのうた") || pokeMold.moveName[3].equals("ほろびのうた"))) { return 2; }
    	if (pokeMold.speciesName.equals("プリン") && (pokeMold.moveName[0].equals("プレゼント") || pokeMold.moveName[1].equals("プレゼント") || pokeMold.moveName[2].equals("プレゼント") || pokeMold.moveName[3].equals("プレゼント"))) { return 2; }
    	if (pokeMold.speciesName.equals("プクリン") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("プクリン") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("プクリン") && (pokeMold.moveName[0].equals("てんしのキッス") || pokeMold.moveName[1].equals("てんしのキッス") || pokeMold.moveName[2].equals("てんしのキッス") || pokeMold.moveName[3].equals("てんしのキッス"))) { return 2; }
    	if (pokeMold.speciesName.equals("プクリン") && (pokeMold.moveName[0].equals("ほろびのうた") || pokeMold.moveName[1].equals("ほろびのうた") || pokeMold.moveName[2].equals("ほろびのうた") || pokeMold.moveName[3].equals("ほろびのうた"))) { return 2; }
    	if (pokeMold.speciesName.equals("プクリン") && (pokeMold.moveName[0].equals("プレゼント") || pokeMold.moveName[1].equals("プレゼント") || pokeMold.moveName[2].equals("プレゼント") || pokeMold.moveName[3].equals("プレゼント"))) { return 2; }
    	if (pokeMold.speciesName.equals("ズバット") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ズバット") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ゴルバット") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ゴルバット") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ナゾノクサ") && (pokeMold.moveName[0].equals("こうごうせい") || pokeMold.moveName[1].equals("こうごうせい") || pokeMold.moveName[2].equals("こうごうせい") || pokeMold.moveName[3].equals("こうごうせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("ナゾノクサ") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("クサイハナ") && (pokeMold.moveName[0].equals("こうごうせい") || pokeMold.moveName[1].equals("こうごうせい") || pokeMold.moveName[2].equals("こうごうせい") || pokeMold.moveName[3].equals("こうごうせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("クサイハナ") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ラフレシア") && (pokeMold.moveName[0].equals("こうごうせい") || pokeMold.moveName[1].equals("こうごうせい") || pokeMold.moveName[2].equals("こうごうせい") || pokeMold.moveName[3].equals("こうごうせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("ラフレシア") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("パラス") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("パラス") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("パラス") && (pokeMold.moveName[0].equals("みねうち") || pokeMold.moveName[1].equals("みねうち") || pokeMold.moveName[2].equals("みねうち") || pokeMold.moveName[3].equals("みねうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("パラセクト") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("パラセクト") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("パラセクト") && (pokeMold.moveName[0].equals("みねうち") || pokeMold.moveName[1].equals("みねうち") || pokeMold.moveName[2].equals("みねうち") || pokeMold.moveName[3].equals("みねうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("コンパン") && (pokeMold.moveName[0].equals("バトンタッチ") || pokeMold.moveName[1].equals("バトンタッチ") || pokeMold.moveName[2].equals("バトンタッチ") || pokeMold.moveName[3].equals("バトンタッチ"))) { return 2; }
    	if (pokeMold.speciesName.equals("モルフォン") && (pokeMold.moveName[0].equals("バトンタッチ") || pokeMold.moveName[1].equals("バトンタッチ") || pokeMold.moveName[2].equals("バトンタッチ") || pokeMold.moveName[3].equals("バトンタッチ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ディグダ") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ディグダ") && (pokeMold.moveName[0].equals("げんしのちから") || pokeMold.moveName[1].equals("げんしのちから") || pokeMold.moveName[2].equals("げんしのちから") || pokeMold.moveName[3].equals("げんしのちから"))) { return 2; }
    	if (pokeMold.speciesName.equals("ディグダ") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ディグダ") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("ダグトリオ") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ダグトリオ") && (pokeMold.moveName[0].equals("げんしのちから") || pokeMold.moveName[1].equals("げんしのちから") || pokeMold.moveName[2].equals("げんしのちから") || pokeMold.moveName[3].equals("げんしのちから"))) { return 2; }
    	if (pokeMold.speciesName.equals("ダグトリオ") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ダグトリオ") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニャース") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニャース") && (pokeMold.moveName[0].equals("うらみ") || pokeMold.moveName[1].equals("うらみ") || pokeMold.moveName[2].equals("うらみ") || pokeMold.moveName[3].equals("うらみ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ペルシアン") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ペルシアン") && (pokeMold.moveName[0].equals("うらみ") || pokeMold.moveName[1].equals("うらみ") || pokeMold.moveName[2].equals("うらみ") || pokeMold.moveName[3].equals("うらみ"))) { return 2; }
    	if (pokeMold.speciesName.equals("コダック") && (pokeMold.moveName[0].equals("みやぶる") || pokeMold.moveName[1].equals("みやぶる") || pokeMold.moveName[2].equals("みやぶる") || pokeMold.moveName[3].equals("みやぶる"))) { return 2; }
    	if (pokeMold.speciesName.equals("コダック") && (pokeMold.moveName[0].equals("みらいよち") || pokeMold.moveName[1].equals("みらいよち") || pokeMold.moveName[2].equals("みらいよち") || pokeMold.moveName[3].equals("みらいよち"))) { return 2; }
    	if (pokeMold.speciesName.equals("コダック") && (pokeMold.moveName[0].equals("クロスチョップ") || pokeMold.moveName[1].equals("クロスチョップ") || pokeMold.moveName[2].equals("クロスチョップ") || pokeMold.moveName[3].equals("クロスチョップ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ゴルダック") && (pokeMold.moveName[0].equals("みやぶる") || pokeMold.moveName[1].equals("みやぶる") || pokeMold.moveName[2].equals("みやぶる") || pokeMold.moveName[3].equals("みやぶる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ゴルダック") && (pokeMold.moveName[0].equals("みらいよち") || pokeMold.moveName[1].equals("みらいよち") || pokeMold.moveName[2].equals("みらいよち") || pokeMold.moveName[3].equals("みらいよち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ゴルダック") && (pokeMold.moveName[0].equals("クロスチョップ") || pokeMold.moveName[1].equals("クロスチョップ") || pokeMold.moveName[2].equals("クロスチョップ") || pokeMold.moveName[3].equals("クロスチョップ"))) { return 2; }
    	if (pokeMold.speciesName.equals("マンキー") && (pokeMold.moveName[0].equals("きしかいせい") || pokeMold.moveName[1].equals("きしかいせい") || pokeMold.moveName[2].equals("きしかいせい") || pokeMold.moveName[3].equals("きしかいせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("マンキー") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("マンキー") && (pokeMold.moveName[0].equals("みやぶる") || pokeMold.moveName[1].equals("みやぶる") || pokeMold.moveName[2].equals("みやぶる") || pokeMold.moveName[3].equals("みやぶる"))) { return 2; }
    	if (pokeMold.speciesName.equals("オコリザル") && (pokeMold.moveName[0].equals("きしかいせい") || pokeMold.moveName[1].equals("きしかいせい") || pokeMold.moveName[2].equals("きしかいせい") || pokeMold.moveName[3].equals("きしかいせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("オコリザル") && (pokeMold.moveName[0].equals("ふくろだたき") || pokeMold.moveName[1].equals("ふくろだたき") || pokeMold.moveName[2].equals("ふくろだたき") || pokeMold.moveName[3].equals("ふくろだたき"))) { return 2; }
    	if (pokeMold.speciesName.equals("オコリザル") && (pokeMold.moveName[0].equals("みやぶる") || pokeMold.moveName[1].equals("みやぶる") || pokeMold.moveName[2].equals("みやぶる") || pokeMold.moveName[3].equals("みやぶる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ガーディ") && (pokeMold.moveName[0].equals("かみくだく") || pokeMold.moveName[1].equals("かみくだく") || pokeMold.moveName[2].equals("かみくだく") || pokeMold.moveName[3].equals("かみくだく"))) { return 2; }
    	if (pokeMold.speciesName.equals("ガーディ") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("ウインディ") && (pokeMold.moveName[0].equals("かみくだく") || pokeMold.moveName[1].equals("かみくだく") || pokeMold.moveName[2].equals("かみくだく") || pokeMold.moveName[3].equals("かみくだく"))) { return 2; }
    	if (pokeMold.speciesName.equals("ウインディ") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニョロモ") && (pokeMold.moveName[0].equals("こころのめ") || pokeMold.moveName[1].equals("こころのめ") || pokeMold.moveName[2].equals("こころのめ") || pokeMold.moveName[3].equals("こころのめ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニョロゾ") && (pokeMold.moveName[0].equals("こころのめ") || pokeMold.moveName[1].equals("こころのめ") || pokeMold.moveName[2].equals("こころのめ") || pokeMold.moveName[3].equals("こころのめ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニョロボン") && (pokeMold.moveName[0].equals("こころのめ") || pokeMold.moveName[1].equals("こころのめ") || pokeMold.moveName[2].equals("こころのめ") || pokeMold.moveName[3].equals("こころのめ")) && pokeMold.level < 51) { return 2; }
    	if (pokeMold.speciesName.equals("ケーシィ") && (pokeMold.moveName[0].equals("アンコール") || pokeMold.moveName[1].equals("アンコール") || pokeMold.moveName[2].equals("アンコール") || pokeMold.moveName[3].equals("アンコール"))) { return 2; }
    	if (pokeMold.speciesName.equals("ユンゲラー") && (pokeMold.moveName[0].equals("アンコール") || pokeMold.moveName[1].equals("アンコール") || pokeMold.moveName[2].equals("アンコール") || pokeMold.moveName[3].equals("アンコール"))) { return 2; }
    	if (pokeMold.speciesName.equals("フーディン") && (pokeMold.moveName[0].equals("アンコール") || pokeMold.moveName[1].equals("アンコール") || pokeMold.moveName[2].equals("アンコール") || pokeMold.moveName[3].equals("アンコール"))) { return 2; }
    	if (pokeMold.speciesName.equals("ワンリキー") && (pokeMold.moveName[0].equals("アンコール") || pokeMold.moveName[1].equals("アンコール") || pokeMold.moveName[2].equals("アンコール") || pokeMold.moveName[3].equals("アンコール"))) { return 2; }
    	if (pokeMold.speciesName.equals("ゴーリキー") && (pokeMold.moveName[0].equals("アンコール") || pokeMold.moveName[1].equals("アンコール") || pokeMold.moveName[2].equals("アンコール") || pokeMold.moveName[3].equals("アンコール"))) { return 2; }
    	if (pokeMold.speciesName.equals("カイリキー") && (pokeMold.moveName[0].equals("アンコール") || pokeMold.moveName[1].equals("アンコール") || pokeMold.moveName[2].equals("アンコール") || pokeMold.moveName[3].equals("アンコール"))) { return 2; }
    	if (pokeMold.speciesName.equals("マダツボミ") && (pokeMold.moveName[0].equals("こうごうせい") || pokeMold.moveName[1].equals("こうごうせい") || pokeMold.moveName[2].equals("こうごうせい") || pokeMold.moveName[3].equals("こうごうせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("マダツボミ") && (pokeMold.moveName[0].equals("アンコール") || pokeMold.moveName[1].equals("アンコール") || pokeMold.moveName[2].equals("アンコール") || pokeMold.moveName[3].equals("アンコール"))) { return 2; }
    	if (pokeMold.speciesName.equals("ウツドン") && (pokeMold.moveName[0].equals("こうごうせい") || pokeMold.moveName[1].equals("こうごうせい") || pokeMold.moveName[2].equals("こうごうせい") || pokeMold.moveName[3].equals("こうごうせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("ウツドン") && (pokeMold.moveName[0].equals("アンコール") || pokeMold.moveName[1].equals("アンコール") || pokeMold.moveName[2].equals("アンコール") || pokeMold.moveName[3].equals("アンコール"))) { return 2; }
    	if (pokeMold.speciesName.equals("ウツボット") && (pokeMold.moveName[0].equals("こうごうせい") || pokeMold.moveName[1].equals("こうごうせい") || pokeMold.moveName[2].equals("こうごうせい") || pokeMold.moveName[3].equals("こうごうせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("ウツボット") && (pokeMold.moveName[0].equals("アンコール") || pokeMold.moveName[1].equals("アンコール") || pokeMold.moveName[2].equals("アンコール") || pokeMold.moveName[3].equals("アンコール"))) { return 2; }
    	if (pokeMold.speciesName.equals("メノクラゲ") && (pokeMold.moveName[0].equals("こうそくスピン") || pokeMold.moveName[1].equals("こうそくスピン") || pokeMold.moveName[2].equals("こうそくスピン") || pokeMold.moveName[3].equals("こうそくスピン"))) { return 2; }
    	if (pokeMold.speciesName.equals("メノクラゲ") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("メノクラゲ") && (pokeMold.moveName[0].equals("ミラーコート") || pokeMold.moveName[1].equals("ミラーコート") || pokeMold.moveName[2].equals("ミラーコート") || pokeMold.moveName[3].equals("ミラーコート"))) { return 2; }
    	if (pokeMold.speciesName.equals("ドククラゲ") && (pokeMold.moveName[0].equals("こうそくスピン") || pokeMold.moveName[1].equals("こうそくスピン") || pokeMold.moveName[2].equals("こうそくスピン") || pokeMold.moveName[3].equals("こうそくスピン"))) { return 2; }
    	if (pokeMold.speciesName.equals("ドククラゲ") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("ドククラゲ") && (pokeMold.moveName[0].equals("ミラーコート") || pokeMold.moveName[1].equals("ミラーコート") || pokeMold.moveName[2].equals("ミラーコート") || pokeMold.moveName[3].equals("ミラーコート"))) { return 2; }
    	if (pokeMold.speciesName.equals("ポニータ") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ポニータ") && (pokeMold.moveName[0].equals("かえんぐるま") || pokeMold.moveName[1].equals("かえんぐるま") || pokeMold.moveName[2].equals("かえんぐるま") || pokeMold.moveName[3].equals("かえんぐるま"))) { return 2; }
    	if (pokeMold.speciesName.equals("ギャロップ") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ギャロップ") && (pokeMold.moveName[0].equals("かえんぐるま") || pokeMold.moveName[1].equals("かえんぐるま") || pokeMold.moveName[2].equals("かえんぐるま") || pokeMold.moveName[3].equals("かえんぐるま"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヤドン") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヤドン") && (pokeMold.moveName[0].equals("はらだいこ") || pokeMold.moveName[1].equals("はらだいこ") || pokeMold.moveName[2].equals("はらだいこ") || pokeMold.moveName[3].equals("はらだいこ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヤドン") && (pokeMold.moveName[0].equals("みらいよち") || pokeMold.moveName[1].equals("みらいよち") || pokeMold.moveName[2].equals("みらいよち") || pokeMold.moveName[3].equals("みらいよち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヤドラン") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヤドラン") && (pokeMold.moveName[0].equals("はらだいこ") || pokeMold.moveName[1].equals("はらだいこ") || pokeMold.moveName[2].equals("はらだいこ") || pokeMold.moveName[3].equals("はらだいこ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヤドラン") && (pokeMold.moveName[0].equals("みらいよち") || pokeMold.moveName[1].equals("みらいよち") || pokeMold.moveName[2].equals("みらいよち") || pokeMold.moveName[3].equals("みらいよち"))) { return 2; }
    	if (pokeMold.speciesName.equals("カモネギ") && (pokeMold.moveName[0].equals("バトンタッチ") || pokeMold.moveName[1].equals("バトンタッチ") || pokeMold.moveName[2].equals("バトンタッチ") || pokeMold.moveName[3].equals("バトンタッチ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ドードー") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ドードー") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ドードリオ") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ドードリオ") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("パウワウ") && (pokeMold.moveName[0].equals("ほろびのうた") || pokeMold.moveName[1].equals("ほろびのうた") || pokeMold.moveName[2].equals("ほろびのうた") || pokeMold.moveName[3].equals("ほろびのうた"))) { return 2; }
    	if (pokeMold.speciesName.equals("パウワウ") && (pokeMold.moveName[0].equals("アンコール") || pokeMold.moveName[1].equals("アンコール") || pokeMold.moveName[2].equals("アンコール") || pokeMold.moveName[3].equals("アンコール"))) { return 2; }
    	if (pokeMold.speciesName.equals("ジュゴン") && (pokeMold.moveName[0].equals("ほろびのうた") || pokeMold.moveName[1].equals("ほろびのうた") || pokeMold.moveName[2].equals("ほろびのうた") || pokeMold.moveName[3].equals("ほろびのうた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ジュゴン") && (pokeMold.moveName[0].equals("アンコール") || pokeMold.moveName[1].equals("アンコール") || pokeMold.moveName[2].equals("アンコール") || pokeMold.moveName[3].equals("アンコール"))) { return 2; }
    	if (pokeMold.speciesName.equals("ベトベター") && (pokeMold.moveName[0].equals("くろいまなざし") || pokeMold.moveName[1].equals("くろいまなざし") || pokeMold.moveName[2].equals("くろいまなざし") || pokeMold.moveName[3].equals("くろいまなざし"))) { return 2; }
    	if (pokeMold.speciesName.equals("ベトベトン") && (pokeMold.moveName[0].equals("くろいまなざし") || pokeMold.moveName[1].equals("くろいまなざし") || pokeMold.moveName[2].equals("くろいまなざし") || pokeMold.moveName[3].equals("くろいまなざし"))) { return 2; }
    	if (pokeMold.speciesName.equals("シェルダー") && (pokeMold.moveName[0].equals("こうそくスピン") || pokeMold.moveName[1].equals("こうそくスピン") || pokeMold.moveName[2].equals("こうそくスピン") || pokeMold.moveName[3].equals("こうそくスピン"))) { return 2; }
    	if (pokeMold.speciesName.equals("パルシェン") && (pokeMold.moveName[0].equals("こうそくスピン") || pokeMold.moveName[1].equals("こうそくスピン") || pokeMold.moveName[2].equals("こうそくスピン") || pokeMold.moveName[3].equals("こうそくスピン"))) { return 2; }
    	if (pokeMold.speciesName.equals("ゴース") && (pokeMold.moveName[0].equals("ほろびのうた") || pokeMold.moveName[1].equals("ほろびのうた") || pokeMold.moveName[2].equals("ほろびのうた") || pokeMold.moveName[3].equals("ほろびのうた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ゴースト") && (pokeMold.moveName[0].equals("ほろびのうた") || pokeMold.moveName[1].equals("ほろびのうた") || pokeMold.moveName[2].equals("ほろびのうた") || pokeMold.moveName[3].equals("ほろびのうた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ゲンガー") && (pokeMold.moveName[0].equals("ほろびのうた") || pokeMold.moveName[1].equals("ほろびのうた") || pokeMold.moveName[2].equals("ほろびのうた") || pokeMold.moveName[3].equals("ほろびのうた"))) { return 2; }
    	if (pokeMold.speciesName.equals("イワーク") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("クラブ") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("キングラー") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("タマタマ") && (pokeMold.moveName[0].equals("げんしのちから") || pokeMold.moveName[1].equals("げんしのちから") || pokeMold.moveName[2].equals("げんしのちから") || pokeMold.moveName[3].equals("げんしのちから"))) { return 2; }
    	if (pokeMold.speciesName.equals("タマタマ") && (pokeMold.moveName[0].equals("こうごうせい") || pokeMold.moveName[1].equals("こうごうせい") || pokeMold.moveName[2].equals("こうごうせい") || pokeMold.moveName[3].equals("こうごうせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("タマタマ") && (pokeMold.moveName[0].equals("つきのひかり") || pokeMold.moveName[1].equals("つきのひかり") || pokeMold.moveName[2].equals("つきのひかり") || pokeMold.moveName[3].equals("つきのひかり"))) { return 2; }
    	if (pokeMold.speciesName.equals("ナッシー") && (pokeMold.moveName[0].equals("げんしのちから") || pokeMold.moveName[1].equals("げんしのちから") || pokeMold.moveName[2].equals("げんしのちから") || pokeMold.moveName[3].equals("げんしのちから"))) { return 2; }
    	if (pokeMold.speciesName.equals("ナッシー") && (pokeMold.moveName[0].equals("こうごうせい") || pokeMold.moveName[1].equals("こうごうせい") || pokeMold.moveName[2].equals("こうごうせい") || pokeMold.moveName[3].equals("こうごうせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("ナッシー") && (pokeMold.moveName[0].equals("つきのひかり") || pokeMold.moveName[1].equals("つきのひかり") || pokeMold.moveName[2].equals("つきのひかり") || pokeMold.moveName[3].equals("つきのひかり"))) { return 2; }
    	if (pokeMold.speciesName.equals("カラカラ") && (pokeMold.moveName[0].equals("げんしのちから") || pokeMold.moveName[1].equals("げんしのちから") || pokeMold.moveName[2].equals("げんしのちから") || pokeMold.moveName[3].equals("げんしのちから"))) { return 2; }
    	if (pokeMold.speciesName.equals("カラカラ") && (pokeMold.moveName[0].equals("はらだいこ") || pokeMold.moveName[1].equals("はらだいこ") || pokeMold.moveName[2].equals("はらだいこ") || pokeMold.moveName[3].equals("はらだいこ"))) { return 2; }
    	if (pokeMold.speciesName.equals("カラカラ") && (pokeMold.moveName[0].equals("ほろびのうた") || pokeMold.moveName[1].equals("ほろびのうた") || pokeMold.moveName[2].equals("ほろびのうた") || pokeMold.moveName[3].equals("ほろびのうた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ガラガラ") && (pokeMold.moveName[0].equals("げんしのちから") || pokeMold.moveName[1].equals("げんしのちから") || pokeMold.moveName[2].equals("げんしのちから") || pokeMold.moveName[3].equals("げんしのちから"))) { return 2; }
    	if (pokeMold.speciesName.equals("ガラガラ") && (pokeMold.moveName[0].equals("はらだいこ") || pokeMold.moveName[1].equals("はらだいこ") || pokeMold.moveName[2].equals("はらだいこ") || pokeMold.moveName[3].equals("はらだいこ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ガラガラ") && (pokeMold.moveName[0].equals("ほろびのうた") || pokeMold.moveName[1].equals("ほろびのうた") || pokeMold.moveName[2].equals("ほろびのうた") || pokeMold.moveName[3].equals("ほろびのうた"))) { return 2; }
    	if (pokeMold.speciesName.equals("サワムラー") && (pokeMold.moveName[0].equals("こうそくスピン") || pokeMold.moveName[1].equals("こうそくスピン") || pokeMold.moveName[2].equals("こうそくスピン") || pokeMold.moveName[3].equals("こうそくスピン"))) { return 2; }
    	if (pokeMold.speciesName.equals("サワムラー") && (pokeMold.moveName[0].equals("こころのめ") || pokeMold.moveName[1].equals("こころのめ") || pokeMold.moveName[2].equals("こころのめ") || pokeMold.moveName[3].equals("こころのめ")) && pokeMold.level < 31) { return 2; }
    	if (pokeMold.speciesName.equals("サワムラー") && (pokeMold.moveName[0].equals("マッハパンチ") || pokeMold.moveName[1].equals("マッハパンチ") || pokeMold.moveName[2].equals("マッハパンチ") || pokeMold.moveName[3].equals("マッハパンチ"))) { return 2; }
    	if (pokeMold.speciesName.equals("エビワラー") && (pokeMold.moveName[0].equals("こうそくスピン") || pokeMold.moveName[1].equals("こうそくスピン") || pokeMold.moveName[2].equals("こうそくスピン") || pokeMold.moveName[3].equals("こうそくスピン"))) { return 2; }
    	if (pokeMold.speciesName.equals("エビワラー") && (pokeMold.moveName[0].equals("こころのめ") || pokeMold.moveName[1].equals("こころのめ") || pokeMold.moveName[2].equals("こころのめ") || pokeMold.moveName[3].equals("こころのめ"))) { return 2; }
    	if (pokeMold.speciesName.equals("エビワラー") && (pokeMold.moveName[0].equals("マッハパンチ") || pokeMold.moveName[1].equals("マッハパンチ") || pokeMold.moveName[2].equals("マッハパンチ") || pokeMold.moveName[3].equals("マッハパンチ")) && pokeMold.level < 32) { return 2; }
    	if (pokeMold.speciesName.equals("ベロリンガ") && (pokeMold.moveName[0].equals("はらだいこ") || pokeMold.moveName[1].equals("はらだいこ") || pokeMold.moveName[2].equals("はらだいこ") || pokeMold.moveName[3].equals("はらだいこ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ベロリンガ") && (pokeMold.moveName[0].equals("マグニチュード") || pokeMold.moveName[1].equals("マグニチュード") || pokeMold.moveName[2].equals("マグニチュード") || pokeMold.moveName[3].equals("マグニチュード"))) { return 2; }
    	if (pokeMold.speciesName.equals("ドガース") && (pokeMold.moveName[0].equals("いたみわけ") || pokeMold.moveName[1].equals("いたみわけ") || pokeMold.moveName[2].equals("いたみわけ") || pokeMold.moveName[3].equals("いたみわけ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ドガース") && (pokeMold.moveName[0].equals("みちづれ") || pokeMold.moveName[1].equals("みちづれ") || pokeMold.moveName[2].equals("みちづれ") || pokeMold.moveName[3].equals("みちづれ"))) { return 2; }
    	if (pokeMold.speciesName.equals("マタドガス") && (pokeMold.moveName[0].equals("いたみわけ") || pokeMold.moveName[1].equals("いたみわけ") || pokeMold.moveName[2].equals("いたみわけ") || pokeMold.moveName[3].equals("いたみわけ"))) { return 2; }
    	if (pokeMold.speciesName.equals("マタドガス") && (pokeMold.moveName[0].equals("みちづれ") || pokeMold.moveName[1].equals("みちづれ") || pokeMold.moveName[2].equals("みちづれ") || pokeMold.moveName[3].equals("みちづれ"))) { return 2; }
    	if (pokeMold.speciesName.equals("サイホーン") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("サイホーン") && (pokeMold.moveName[0].equals("かみくだく") || pokeMold.moveName[1].equals("かみくだく") || pokeMold.moveName[2].equals("かみくだく") || pokeMold.moveName[3].equals("かみくだく"))) { return 2; }
    	if (pokeMold.speciesName.equals("サイホーン") && (pokeMold.moveName[0].equals("きしかいせい") || pokeMold.moveName[1].equals("きしかいせい") || pokeMold.moveName[2].equals("きしかいせい") || pokeMold.moveName[3].equals("きしかいせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("サイホーン") && (pokeMold.moveName[0].equals("マグニチュード") || pokeMold.moveName[1].equals("マグニチュード") || pokeMold.moveName[2].equals("マグニチュード") || pokeMold.moveName[3].equals("マグニチュード"))) { return 2; }
    	if (pokeMold.speciesName.equals("サイドン") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("サイドン") && (pokeMold.moveName[0].equals("かみくだく") || pokeMold.moveName[1].equals("かみくだく") || pokeMold.moveName[2].equals("かみくだく") || pokeMold.moveName[3].equals("かみくだく"))) { return 2; }
    	if (pokeMold.speciesName.equals("サイドン") && (pokeMold.moveName[0].equals("きしかいせい") || pokeMold.moveName[1].equals("きしかいせい") || pokeMold.moveName[2].equals("きしかいせい") || pokeMold.moveName[3].equals("きしかいせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("サイドン") && (pokeMold.moveName[0].equals("マグニチュード") || pokeMold.moveName[1].equals("マグニチュード") || pokeMold.moveName[2].equals("マグニチュード") || pokeMold.moveName[3].equals("マグニチュード"))) { return 2; }
    	if (pokeMold.speciesName.equals("ラッキー") && (pokeMold.moveName[0].equals("いやしのすず") || pokeMold.moveName[1].equals("いやしのすず") || pokeMold.moveName[2].equals("いやしのすず") || pokeMold.moveName[3].equals("いやしのすず"))) { return 2; }
    	if (pokeMold.speciesName.equals("ラッキー") && (pokeMold.moveName[0].equals("プレゼント") || pokeMold.moveName[1].equals("プレゼント") || pokeMold.moveName[2].equals("プレゼント") || pokeMold.moveName[3].equals("プレゼント"))) { return 2; }
    	if (pokeMold.speciesName.equals("モンジャラ") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ガルーラ") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("ガルーラ") && (pokeMold.moveName[0].equals("みやぶる") || pokeMold.moveName[1].equals("みやぶる") || pokeMold.moveName[2].equals("みやぶる") || pokeMold.moveName[3].equals("みやぶる"))) { return 2; }
    	if (pokeMold.speciesName.equals("タッツー") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("タッツー") && (pokeMold.moveName[0].equals("オクタンほう") || pokeMold.moveName[1].equals("オクタンほう") || pokeMold.moveName[2].equals("オクタンほう") || pokeMold.moveName[3].equals("オクタンほう"))) { return 2; }
    	if (pokeMold.speciesName.equals("シードラ") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("シードラ") && (pokeMold.moveName[0].equals("オクタンほう") || pokeMold.moveName[1].equals("オクタンほう") || pokeMold.moveName[2].equals("オクタンほう") || pokeMold.moveName[3].equals("オクタンほう"))) { return 2; }
    	if (pokeMold.speciesName.equals("バリヤード") && (pokeMold.moveName[0].equals("みらいよち") || pokeMold.moveName[1].equals("みらいよち") || pokeMold.moveName[2].equals("みらいよち") || pokeMold.moveName[3].equals("みらいよち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ストライク") && (pokeMold.moveName[0].equals("きしかいせい") || pokeMold.moveName[1].equals("きしかいせい") || pokeMold.moveName[2].equals("きしかいせい") || pokeMold.moveName[3].equals("きしかいせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("ストライク") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("ストライク") && (pokeMold.moveName[0].equals("バトンタッチ") || pokeMold.moveName[1].equals("バトンタッチ") || pokeMold.moveName[2].equals("バトンタッチ") || pokeMold.moveName[3].equals("バトンタッチ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ルージュラ") && (pokeMold.moveName[0].equals("てんしのキッス") || pokeMold.moveName[1].equals("てんしのキッス") || pokeMold.moveName[2].equals("てんしのキッス") || pokeMold.moveName[3].equals("てんしのキッス"))) { return 2; }
    	if (pokeMold.speciesName.equals("エレブー") && (pokeMold.moveName[0].equals("クロスチョップ") || pokeMold.moveName[1].equals("クロスチョップ") || pokeMold.moveName[2].equals("クロスチョップ") || pokeMold.moveName[3].equals("クロスチョップ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ブーバー") && (pokeMold.moveName[0].equals("クロスチョップ") || pokeMold.moveName[1].equals("クロスチョップ") || pokeMold.moveName[2].equals("クロスチョップ") || pokeMold.moveName[3].equals("クロスチョップ"))) { return 2; }
    	if (pokeMold.speciesName.equals("カイロス") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ラプラス") && (pokeMold.moveName[0].equals("みやぶる") || pokeMold.moveName[1].equals("みやぶる") || pokeMold.moveName[2].equals("みやぶる") || pokeMold.moveName[3].equals("みやぶる"))) { return 2; }
    	if (pokeMold.speciesName.equals("イーブイ") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("イーブイ") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("シャワーズ") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("シャワーズ") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("サンダース") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("サンダース") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ブースター") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ブースター") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("カブト") && (pokeMold.moveName[0].equals("こうそくスピン") || pokeMold.moveName[1].equals("こうそくスピン") || pokeMold.moveName[2].equals("こうそくスピン") || pokeMold.moveName[3].equals("こうそくスピン"))) { return 2; }
    	if (pokeMold.speciesName.equals("カブト") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("カブトプス") && (pokeMold.moveName[0].equals("こうそくスピン") || pokeMold.moveName[1].equals("こうそくスピン") || pokeMold.moveName[2].equals("こうそくスピン") || pokeMold.moveName[3].equals("こうそくスピン"))) { return 2; }
    	if (pokeMold.speciesName.equals("カブトプス") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("プテラ") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("プテラ") && (pokeMold.moveName[0].equals("みやぶる") || pokeMold.moveName[1].equals("みやぶる") || pokeMold.moveName[2].equals("みやぶる") || pokeMold.moveName[3].equals("みやぶる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ミニリュウ") && (pokeMold.moveName[0].equals("しんそく") || pokeMold.moveName[1].equals("しんそく") || pokeMold.moveName[2].equals("しんそく") || pokeMold.moveName[3].equals("しんそく"))) { return 2; }
    	if (pokeMold.speciesName.equals("ハクリュー") && (pokeMold.moveName[0].equals("しんそく") || pokeMold.moveName[1].equals("しんそく") || pokeMold.moveName[2].equals("しんそく") || pokeMold.moveName[3].equals("しんそく"))) { return 2; }
    	if (pokeMold.speciesName.equals("カイリュー") && (pokeMold.moveName[0].equals("しんそく") || pokeMold.moveName[1].equals("しんそく") || pokeMold.moveName[2].equals("しんそく") || pokeMold.moveName[3].equals("しんそく"))) { return 2; }
    	if (pokeMold.speciesName.equals("クロバット") && (pokeMold.moveName[0].equals("おいうち") || pokeMold.moveName[1].equals("おいうち") || pokeMold.moveName[2].equals("おいうち") || pokeMold.moveName[3].equals("おいうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("クロバット") && (pokeMold.moveName[0].equals("だましうち") || pokeMold.moveName[1].equals("だましうち") || pokeMold.moveName[2].equals("だましうち") || pokeMold.moveName[3].equals("だましうち"))) { return 2; }
    	if (pokeMold.speciesName.equals("キレイハナ") && (pokeMold.moveName[0].equals("こうごうせい") || pokeMold.moveName[1].equals("こうごうせい") || pokeMold.moveName[2].equals("こうごうせい") || pokeMold.moveName[3].equals("こうごうせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("キレイハナ") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ニョロトノ") && (pokeMold.moveName[0].equals("こころのめ") || pokeMold.moveName[1].equals("こころのめ") || pokeMold.moveName[2].equals("こころのめ") || pokeMold.moveName[3].equals("こころのめ"))) { return 2; }
    	if (pokeMold.speciesName.equals("エーフィ") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("エーフィ") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ブラッキー") && (pokeMold.moveName[0].equals("あまえる") || pokeMold.moveName[1].equals("あまえる") || pokeMold.moveName[2].equals("あまえる") || pokeMold.moveName[3].equals("あまえる"))) { return 2; }
    	if (pokeMold.speciesName.equals("ブラッキー") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヤドキング") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヤドキング") && (pokeMold.moveName[0].equals("はらだいこ") || pokeMold.moveName[1].equals("はらだいこ") || pokeMold.moveName[2].equals("はらだいこ") || pokeMold.moveName[3].equals("はらだいこ"))) { return 2; }
    	if (pokeMold.speciesName.equals("ヤドキング") && (pokeMold.moveName[0].equals("みらいよち") || pokeMold.moveName[1].equals("みらいよち") || pokeMold.moveName[2].equals("みらいよち") || pokeMold.moveName[3].equals("みらいよち"))) { return 2; }
    	if (pokeMold.speciesName.equals("ハガネール") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("ハッサム") && (pokeMold.moveName[0].equals("きしかいせい") || pokeMold.moveName[1].equals("きしかいせい") || pokeMold.moveName[2].equals("きしかいせい") || pokeMold.moveName[3].equals("きしかいせい"))) { return 2; }
    	if (pokeMold.speciesName.equals("ハッサム") && (pokeMold.moveName[0].equals("しんぴのまもり") || pokeMold.moveName[1].equals("しんぴのまもり") || pokeMold.moveName[2].equals("しんぴのまもり") || pokeMold.moveName[3].equals("しんぴのまもり"))) { return 2; }
    	if (pokeMold.speciesName.equals("ハッサム") && (pokeMold.moveName[0].equals("バトンタッチ") || pokeMold.moveName[1].equals("バトンタッチ") || pokeMold.moveName[2].equals("バトンタッチ") || pokeMold.moveName[3].equals("バトンタッチ"))) { return 2; }
    	if (pokeMold.speciesName.equals("キングドラ") && (pokeMold.moveName[0].equals("じたばた") || pokeMold.moveName[1].equals("じたばた") || pokeMold.moveName[2].equals("じたばた") || pokeMold.moveName[3].equals("じたばた"))) { return 2; }
    	if (pokeMold.speciesName.equals("キングドラ") && (pokeMold.moveName[0].equals("オクタンほう") || pokeMold.moveName[1].equals("オクタンほう") || pokeMold.moveName[2].equals("オクタンほう") || pokeMold.moveName[3].equals("オクタンほう"))) { return 2; }
    	if (pokeMold.speciesName.equals("ハピナス") && (pokeMold.moveName[0].equals("いやしのすず") || pokeMold.moveName[1].equals("いやしのすず") || pokeMold.moveName[2].equals("いやしのすず") || pokeMold.moveName[3].equals("いやしのすず"))) { return 2; }
    	if (pokeMold.speciesName.equals("ハピナス") && (pokeMold.moveName[0].equals("プレゼント") || pokeMold.moveName[1].equals("プレゼント") || pokeMold.moveName[2].equals("プレゼント") || pokeMold.moveName[3].equals("プレゼント"))) { return 2; }

    	// それ以外は第一世代
    	return 1;

    }

	/* バルキーチェックの対象になるかどうかを判定するメソッド
	 *   引数　：PokeMoldオブジェクト、育成可能な下限の世代（int）
	 *   戻り値：チェック対象（boolean）
	 *   例外　：無し
	 */
    public boolean setTyrogueCheckFlag(PokeMold pokeMold, int pokeBreedGen) {

    	// バルキー進化系でなければチェック対象外
    	if (!pokeMold.speciesName.equals("サワムラー") && !pokeMold.speciesName.equals("エビワラー") && !pokeMold.speciesName.equals("カポエラー")) { return false; }

    	// 第一世代育成不可ならチェック対象
    	if (pokeBreedGen == 2) { return true; }

    	// とびひざげりやピヨピヨパンチを覚えるケースはチェック対象
    	if (pokeMold.speciesName.equals("サワムラー") && (pokeMold.moveName[0].equals("とびひざげり") || pokeMold.moveName[1].equals("とびひざげり") || pokeMold.moveName[2].equals("とびひざげり") || pokeMold.moveName[3].equals("とびひざげり")) && pokeMold.level < 26) { return true; }
    	if (pokeMold.speciesName.equals("サワムラー") && (pokeMold.moveName[0].equals("ピヨピヨパンチ") || pokeMold.moveName[1].equals("ピヨピヨパンチ") || pokeMold.moveName[2].equals("ピヨピヨパンチ") || pokeMold.moveName[3].equals("ピヨピヨパンチ"))) { return true; }
    	if (pokeMold.speciesName.equals("エビワラー") && (pokeMold.moveName[0].equals("とびひざげり") || pokeMold.moveName[1].equals("とびひざげり") || pokeMold.moveName[2].equals("とびひざげり") || pokeMold.moveName[3].equals("とびひざげり"))) { return true; }
    	if (pokeMold.speciesName.equals("エビワラー") && (pokeMold.moveName[0].equals("ピヨピヨパンチ") || pokeMold.moveName[1].equals("ピヨピヨパンチ") || pokeMold.moveName[2].equals("ピヨピヨパンチ") || pokeMold.moveName[3].equals("ピヨピヨパンチ"))) { return true; }

    	// それ以外（サワムラーやエビワラーを第一世代で捕獲する）ならチェック対象外
    	return false;

    }

}
