package validation;

import java.util.Arrays;

import mold.PokeMold;

/*
*  LevelLimitationCheckForNC2000クラス
*
*  パーティがニンテンドウカップ2000のレベル制限をクリアしているかをチェックするクラスです。
*  ポケモン数のチェックもここで行います。
*
*  変更履歴
*  2021/05/08 新規作成
*
*/

public class LevelLimitationCheckForNC2000 {

	/* レベル制限をチェックするメソッド
	 *   引数　：PokeMold配列（要素数1～6）、ValidationMessageStoreオブジェクト
	 *   戻り値：無し
	 *   例外　：無し
	 */
    public void execute(PokeMold[] pokeMoldArray, ValidationMessageStore validationMessageStore) {

    	// レベル配列
    	int[] levelList = {0,0,0,0,0,0};

    	// レベル格納・ポケモン数チェック
    	int i = 0;
    	while(i < 6 && pokeMoldArray[i] != null){
    		levelList[i] = pokeMoldArray[i].level;
    		i++;
    	}
    	if (i != 6) {
    		validationMessageStore.errorMessagesList.add("・パーティ内のポケモン数は６にして下さい。");
    		return;
    	}

    	// レベルの昇順ソート
    	Arrays.sort(levelList);

    	// レベル下限チェック
    	if (levelList[0] < 50) {
    		validationMessageStore.errorMessagesList.add("・パーティ内のポケモンのレベルは50を下回らないようにして下さい。");
    	}

    	// レベル上限チェック
    	if (levelList[5] > 55) {
    		validationMessageStore.errorMessagesList.add("・パーティ内のポケモンのレベルは55を上回らないようにして下さい。");
    	}

    	// 155以内選出存在チェック
    	if ((levelList[0] + levelList[1] + levelList[2]) > 155) {
    		validationMessageStore.errorMessagesList.add("・合計レベルが155以下になるようにパーティ全体のレベルを調整して下さい");
    	}

    	return;

    }

}
