package validation;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;

import mold.PokeMold;

/*
*  MoveBlackListCheckクラス
*
*  各種族について、技の両立判定を行います。
*
*  変更履歴
*  2021/05/09 新規作成
*
*/

public class MoveBlackListCheck {

	// ブラックリストCSVファイルから読み込んだデータを保持
	private String[] dataRecord = new String[5]; // 読み込んだ最新のレコード
	public List<String[]> dataList2 = new ArrayList<String[]>(); // 両立２つ用の保持領域
	public List<String[]> dataList3 = new ArrayList<String[]>(); // 両立３つ用の保持領域

	// CSVファイル読み込みステータス
	public int CSVFileReadStatus = -1; // -1は未読み込み、0は読込済み、1はファイル未存在、2は読込失敗

	/* デフォルトコンストラクタ：種族最低レベルCSVファイル読み込み
	 */
    public MoveBlackListCheck() {
    	readCSV("sub_tools" + "\\" + "004_Validation_Check" + "\\" + "Data");
    }

    /* コンストラクタ：ホワイトリストCSVファイル読み込み（引数でフォルダ指定）
	 */
    public MoveBlackListCheck(String dataForder) {
    	readCSV(dataForder);
    }

    /* 種族最低レベルCSVファイル読み込みメソッド
     *   引数　：CSVファイルパス
	 *   戻り値：無し
	 *   例外　：無し
     */
    public void readCSV(String dataForder) {
    	File file = new File(dataForder + "\\moveBlackList.csv");
        if (!file.exists()) {
        	CSVFileReadStatus = 1;
        	return;
        }
        BufferedReader br = null;

        try {
        	br = new BufferedReader(new InputStreamReader(new FileInputStream(file),"SJIS"));
        	String str = br.readLine();
        	if(str == null) {
        		throw new NullPointerException();
        	} else {
        		while(str != null){
        			dataRecord = str.split("\\,", 0);
        			if (dataRecord[3].equals("")) {
        				dataList2.add(dataRecord);
        			} else {
        				dataList3.add(dataRecord);
        			}
        			str = br.readLine();
        		}
        	}
        	CSVFileReadStatus = 0;
        } catch (Exception e) {
        	CSVFileReadStatus = 2;
        } finally {
        	try {
				br.close();
			} catch (IOException e) {
			}
        }
        return;
    }

	/* 技のブラックリストチェックするメソッド
	 *   引数　：PokeMoldオブジェクト、ValidationMessageStoreオブジェクト、MoveSJISSorterオブジェクト
	 *   戻り値：無し
	 *   例外　：無し
	 */
    public void execute(PokeMold pokeMold, ValidationMessageStore validationMessageStore, MoveSJISSorter moveSJISSorter) {

    	// 技のコンビネーションの作成
    	String[] moveName2 = new String[2];
    	List<String[]> moveNameList2 = new ArrayList<String[]>();
    	String[] moveName3 = new String[3];
    	List<String[]> moveNameList3 = new ArrayList<String[]>();
    	String[] moveNameSorted = new String[4];
    	moveNameSorted = moveSJISSorter.execute(pokeMold.moveName);
    	if (moveNameSorted[1] != null) {
    		moveName2 = new String[2];
    		moveName2[0] = moveNameSorted[0];
    		moveName2[1] = moveNameSorted[1];
    		moveNameList2.add(moveName2);
    	}
    	if (moveNameSorted[2] != null) {
    		moveName2 = new String[2];
    		moveName2[0] = moveNameSorted[0];
    		moveName2[1] = moveNameSorted[2];
    		moveNameList2.add(moveName2);
    		moveName2 = new String[2];
    		moveName2[0] = moveNameSorted[1];
    		moveName2[1] = moveNameSorted[2];
    		moveNameList2.add(moveName2);
    		moveName3 = new String[3];
    		moveName3[0] = moveNameSorted[0];
    		moveName3[1] = moveNameSorted[1];
    		moveName3[2] = moveNameSorted[2];
    		moveNameList3.add(moveName3);
    	}
    	if (moveNameSorted[3] != null) {
    		moveName2 = new String[2];
    		moveName2[0] = moveNameSorted[0];
    		moveName2[1] = moveNameSorted[3];
    		moveNameList2.add(moveName2);
    		moveName2 = new String[2];
    		moveName2[0] = moveNameSorted[1];
    		moveName2[1] = moveNameSorted[3];
    		moveNameList2.add(moveName2);
    		moveName2 = new String[2];
    		moveName2[0] = moveNameSorted[2];
    		moveName2[1] = moveNameSorted[3];
    		moveNameList2.add(moveName2);
    		moveName3 = new String[3];
    		moveName3[0] = moveNameSorted[0];
    		moveName3[1] = moveNameSorted[1];
    		moveName3[2] = moveNameSorted[3];
    		moveNameList3.add(moveName3);
    		moveName3 = new String[3];
    		moveName3[0] = moveNameSorted[0];
    		moveName3[1] = moveNameSorted[2];
    		moveName3[2] = moveNameSorted[3];
    		moveNameList3.add(moveName3);
    		moveName3 = new String[3];
    		moveName3[0] = moveNameSorted[1];
    		moveName3[1] = moveNameSorted[2];
    		moveName3[2] = moveNameSorted[3];
    		moveNameList3.add(moveName3);
    	}

    	// メモリに格納したCSVファイルから当該種族のデータのみ抜き出し
    	int state = 0;
    	List<String[]> dataListSpecies2 = new ArrayList<String[]>();
    	List<String[]> dataListSpecies3 = new ArrayList<String[]>();
    	for (String[] currentRecord : dataList2) {
    		if (state == 0 && pokeMold.speciesName.equals(currentRecord[0])) {
    			state = 1;
    			dataListSpecies2.add(currentRecord);
    			continue;
    		} else if (state == 1 && pokeMold.speciesName.equals(currentRecord[0])) {
    			dataListSpecies2.add(currentRecord);
    		} else if (state == 1 && !pokeMold.speciesName.equals(currentRecord[0])) {
    			state = 2;
    			break;
    		}
    	}
    	state = 0;
    	for (String[] currentRecord : dataList3) {
    		if (state == 0 && pokeMold.speciesName.equals(currentRecord[0])) {
    			state = 1;
    			dataListSpecies3.add(currentRecord);
    			continue;
    		} else if (state == 1 && pokeMold.speciesName.equals(currentRecord[0])) {
    			dataListSpecies3.add(currentRecord);
    		} else if (state == 1 && !pokeMold.speciesName.equals(currentRecord[0])) {
    			state = 2;
    			break;
    		}
    	}

    	// 当該種族のデータを用いてブラックリストチェックを実施
    	for (String[] currentConbination : moveNameList2) {
    		boolean isFound = false;
    		int lowerLimitLevel = 0;
    		for (String[] currentRecord : dataListSpecies2) {
    			if (currentConbination[0].equals(currentRecord[1]) && currentConbination[1].equals(currentRecord[2])) {
    				isFound = true;
    				lowerLimitLevel = Integer.parseInt(currentRecord[4]);
    				break;
    			}
    		}
    		if (isFound && lowerLimitLevel == 256) {
    			validationMessageStore.errorMessagesList.add("・" + pokeMold.speciesName + "は" + currentConbination[0] + "と" + currentConbination[1] + "を併用できません。");
    		} else if (isFound && pokeMold.level < lowerLimitLevel) {
    			validationMessageStore.errorMessagesList.add("・" + pokeMold.speciesName + "は" + lowerLimitLevel + "以上のレベルでないと" + currentConbination[0] + "と" + currentConbination[1] + "を併用できません。");
    		}
    	}
    	for (String[] currentConbination : moveNameList3) {
    		boolean isFound = false;
    		int lowerLimitLevel = 0;
    		for (String[] currentRecord : dataListSpecies3) {
    			if (currentConbination[0].equals(currentRecord[1]) && currentConbination[1].equals(currentRecord[2]) && currentConbination[2].equals(currentRecord[3])) {
    				isFound = true;
    				lowerLimitLevel = Integer.parseInt(currentRecord[4]);
    				break;
    			}
    		}
    		if (isFound && lowerLimitLevel == 256) {
    			validationMessageStore.errorMessagesList.add("・" + pokeMold.speciesName + "は" + currentConbination[0] + "と" + currentConbination[1] + "と" + currentConbination[2] + "を併用できません。");
    		} else if (isFound && pokeMold.level < lowerLimitLevel) {
    			validationMessageStore.errorMessagesList.add("・" + pokeMold.speciesName + "は" + lowerLimitLevel + "以上のレベルでないと" + currentConbination[0] + "と" + currentConbination[1] + "と" + currentConbination[2] + "を併用できません。");
    		}
    	}

    }

}
