package validation;

import java.util.Comparator;
import java.util.HashMap;

/*
*  MoveSJISSorterComparatorクラス
*
*  技配列のSJIS順のソート順を定義します。
*  Validation向けのクラスです。
*
*  変更履歴
*  2021/05/09 新規作成
*
*/

public class MoveSJISSorterComparator implements Comparator<String> {

	// 種族のソート順を格納するHashMap
	public HashMap<String, Integer> moveMap = new HashMap<String, Integer>();

	/* デフォルトコンストラクタ：ソート順作成
	 */
    public MoveSJISSorterComparator() {
    	moveMap.put("１０まんボルト",1);
    	moveMap.put("あくまのキッス",2);
    	moveMap.put("あくむ",3);
    	moveMap.put("あさのひざし",4);
    	moveMap.put("あてみなげ",5);
    	moveMap.put("あなをほる",6);
    	moveMap.put("あばれる",7);
    	moveMap.put("あまいかおり",8);
    	moveMap.put("あまえる",9);
    	moveMap.put("あまごい",10);
    	moveMap.put("あやしいひかり",11);
    	moveMap.put("あわ",12);
    	moveMap.put("いあいぎり",13);
    	moveMap.put("いかり",14);
    	moveMap.put("いかりのまえば",15);
    	moveMap.put("いたみわけ",16);
    	moveMap.put("いとをはく",17);
    	moveMap.put("いばる",18);
    	moveMap.put("いびき",19);
    	moveMap.put("いやしのすず",20);
    	moveMap.put("いやなおと",21);
    	moveMap.put("いわおとし",22);
    	moveMap.put("いわくだき",23);
    	moveMap.put("いわなだれ",24);
    	moveMap.put("うずしお",25);
    	moveMap.put("うたう",26);
    	moveMap.put("うらみ",27);
    	moveMap.put("えんまく",28);
    	moveMap.put("おいうち",29);
    	moveMap.put("おうふくビンタ",30);
    	moveMap.put("おんがえし",31);
    	moveMap.put("かいりき",32);
    	moveMap.put("かえんぐるま",33);
    	moveMap.put("かえんほうしゃ",34);
    	moveMap.put("かくばる",35);
    	moveMap.put("かげぶんしん",36);
    	moveMap.put("かぜおこし",37);
    	moveMap.put("かたくなる",38);
    	moveMap.put("かなしばり",39);
    	moveMap.put("かまいたち",40);
    	moveMap.put("かみくだく",41);
    	moveMap.put("かみつく",42);
    	moveMap.put("かみなり",43);
    	moveMap.put("かみなりパンチ",44);
    	moveMap.put("からてチョップ",45);
    	moveMap.put("からではさむ",46);
    	moveMap.put("からにこもる",47);
    	moveMap.put("からみつく",48);
    	moveMap.put("がまん",49);
    	moveMap.put("きあいだめ",50);
    	moveMap.put("きしかいせい",51);
    	moveMap.put("きゅうけつ",52);
    	moveMap.put("きりさく",53);
    	moveMap.put("くろいきり",54);
    	moveMap.put("くろいまなざし",55);
    	moveMap.put("けたぐり",56);
    	moveMap.put("げきりん",57);
    	moveMap.put("げんしのちから",58);
    	moveMap.put("こうごうせい",59);
    	moveMap.put("こうそくいどう",60);
    	moveMap.put("こうそくスピン",61);
    	moveMap.put("こころのめ",62);
    	moveMap.put("こごえるかぜ",63);
    	moveMap.put("こなゆき",64);
    	moveMap.put("こらえる",65);
    	moveMap.put("ころがる",66);
    	moveMap.put("こわいかお",67);
    	moveMap.put("さいみんじゅつ",68);
    	moveMap.put("したでなめる",69);
    	moveMap.put("しっぽをふる",70);
    	moveMap.put("しびれごな",71);
    	moveMap.put("しめつける",72);
    	moveMap.put("しろいきり",73);
    	moveMap.put("しんそく",74);
    	moveMap.put("しんぴのまもり",75);
    	moveMap.put("じこあんじ",76);
    	moveMap.put("じこさいせい",77);
    	moveMap.put("じごくぐるま",78);
    	moveMap.put("じしん",79);
    	moveMap.put("じたばた",80);
    	moveMap.put("じばく",81);
    	moveMap.put("じわれ",82);
    	moveMap.put("すいとる",83);
    	moveMap.put("すてみタックル",84);
    	moveMap.put("すなあらし",85);
    	moveMap.put("すなかけ",86);
    	moveMap.put("ずつき",87);
    	moveMap.put("せいちょう",88);
    	moveMap.put("せいなるほのお",89);
    	moveMap.put("そらをとぶ",90);
    	moveMap.put("たいあたり",91);
    	moveMap.put("たきのぼり",92);
    	moveMap.put("たたきつける",93);
    	moveMap.put("たつまき",94);
    	moveMap.put("たまなげ",95);
    	moveMap.put("だいばくはつ",96);
    	moveMap.put("だいもんじ",97);
    	moveMap.put("だましうち",98);
    	moveMap.put("ちいさくなる",99);
    	moveMap.put("ちきゅうなげ",100);
    	moveMap.put("ちょうおんぱ",101);
    	moveMap.put("つきのひかり",102);
    	moveMap.put("つつく",103);
    	moveMap.put("つのでつく",104);
    	moveMap.put("つのドリル",105);
    	moveMap.put("つばさでうつ",106);
    	moveMap.put("つるぎのまい",107);
    	moveMap.put("つるのムチ",108);
    	moveMap.put("てんしのキッス",109);
    	moveMap.put("でんきショック",110);
    	moveMap.put("でんこうせっか",111);
    	moveMap.put("でんじは",112);
    	moveMap.put("でんじほう",113);
    	moveMap.put("とける",114);
    	moveMap.put("とげキャノン",115);
    	moveMap.put("とっしん",116);
    	moveMap.put("とびげり",117);
    	moveMap.put("とびひざげり",118);
    	moveMap.put("どくどく",119);
    	moveMap.put("どくのこな",120);
    	moveMap.put("どくばり",121);
    	moveMap.put("どくガス",122);
    	moveMap.put("どろかけ",123);
    	moveMap.put("どろぼう",124);
    	moveMap.put("なきごえ",125);
    	moveMap.put("なみのり",126);
    	moveMap.put("にどげり",127);
    	moveMap.put("にほんばれ",128);
    	moveMap.put("にらみつける",129);
    	moveMap.put("ねごと",130);
    	moveMap.put("ねむりごな",131);
    	moveMap.put("ねむる",132);
    	moveMap.put("ねんりき",133);
    	moveMap.put("のしかかり",134);
    	moveMap.put("のろい",135);
    	moveMap.put("はかいこうせん",136);
    	moveMap.put("はがねのつばさ",137);
    	moveMap.put("はさむ",138);
    	moveMap.put("はたく",139);
    	moveMap.put("はっぱカッター",140);
    	moveMap.put("はなびらのまい",141);
    	moveMap.put("はねる",142);
    	moveMap.put("はらだいこ",143);
    	moveMap.put("ばくれつパンチ",144);
    	moveMap.put("ひかりのかべ",145);
    	moveMap.put("ひっかく",146);
    	moveMap.put("ひっさつまえば",147);
    	moveMap.put("ひのこ",148);
    	moveMap.put("ふきとばし",149);
    	moveMap.put("ふくろだたき",150);
    	moveMap.put("ふぶき",151);
    	moveMap.put("ふみつけ",152);
    	moveMap.put("へびにらみ",153);
    	moveMap.put("へんしん",154);
    	moveMap.put("ほえる",155);
    	moveMap.put("ほのおのうず",156);
    	moveMap.put("ほのおのパンチ",157);
    	moveMap.put("ほろびのうた",158);
    	moveMap.put("まきつく",159);
    	moveMap.put("まきびし",160);
    	moveMap.put("まもる",161);
    	moveMap.put("まるくなる",162);
    	moveMap.put("まわしげり",163);
    	moveMap.put("みがわり",164);
    	moveMap.put("みきり",165);
    	moveMap.put("みずでっぽう",166);
    	moveMap.put("みだれづき",167);
    	moveMap.put("みだれひっかき",168);
    	moveMap.put("みちづれ",169);
    	moveMap.put("みねうち",170);
    	moveMap.put("みやぶる",171);
    	moveMap.put("みらいよち",172);
    	moveMap.put("めざめるパワー",173);
    	moveMap.put("ものまね",174);
    	moveMap.put("やつあたり",175);
    	moveMap.put("やどりぎのタネ",176);
    	moveMap.put("ゆびをふる",177);
    	moveMap.put("ゆめくい",178);
    	moveMap.put("ようかいえき",179);
    	moveMap.put("りゅうのいかり",180);
    	moveMap.put("りゅうのいぶき",181);
    	moveMap.put("れいとうパンチ",182);
    	moveMap.put("れいとうビーム",183);
    	moveMap.put("れんぞくぎり",184);
    	moveMap.put("れんぞくパンチ",185);
    	moveMap.put("わたほうし",186);
    	moveMap.put("わるあがき",187);
    	moveMap.put("アイアンテール",188);
    	moveMap.put("アンコール",189);
    	moveMap.put("エアロブラスト",190);
    	moveMap.put("オーロラビーム",191);
    	moveMap.put("オウムがえし",192);
    	moveMap.put("オクタンほう",193);
    	moveMap.put("カウンター",194);
    	moveMap.put("キノコのほうし",195);
    	moveMap.put("ギガドレイン",196);
    	moveMap.put("クモのす",197);
    	moveMap.put("クラブハンマー",198);
    	moveMap.put("クロスチョップ",199);
    	moveMap.put("ゴッドバード",200);
    	moveMap.put("サイケこうせん",201);
    	moveMap.put("サイコウェーブ",202);
    	moveMap.put("サイコキネシス",203);
    	moveMap.put("シャドーボール",204);
    	moveMap.put("スケッチ",205);
    	moveMap.put("スパーク",206);
    	moveMap.put("スピードスター",207);
    	moveMap.put("スプーンまげ",208);
    	moveMap.put("スモッグ",209);
    	moveMap.put("ソーラービーム",210);
    	moveMap.put("ソニックブーム",211);
    	moveMap.put("タマゴうみ",212);
    	moveMap.put("タマゴばくだん",213);
    	moveMap.put("ダブルニードル",214);
    	moveMap.put("テクスチャー",215);
    	moveMap.put("テクスチャー２",216);
    	moveMap.put("テレポート",217);
    	moveMap.put("トライアタック",218);
    	moveMap.put("トリプルキック",219);
    	moveMap.put("ドわすれ",220);
    	moveMap.put("ドリルくちばし",221);
    	moveMap.put("ナイトヘッド",222);
    	moveMap.put("ネコにこばん",223);
    	moveMap.put("ハイドロポンプ",224);
    	moveMap.put("ハサミギロチン",225);
    	moveMap.put("バトンタッチ",226);
    	moveMap.put("バブルこうせん",227);
    	moveMap.put("バリアー",228);
    	moveMap.put("ピヨピヨパンチ",229);
    	moveMap.put("フラッシュ",230);
    	moveMap.put("プレゼント",231);
    	moveMap.put("ヘドロこうげき",232);
    	moveMap.put("ヘドロばくだん",233);
    	moveMap.put("ホネこんぼう",234);
    	moveMap.put("ホネブーメラン",235);
    	moveMap.put("ボーンラッシュ",236);
    	moveMap.put("マグニチュード",237);
    	moveMap.put("マッハパンチ",238);
    	moveMap.put("ミサイルばり",239);
    	moveMap.put("ミラーコート",240);
    	moveMap.put("ミルクのみ",241);
    	moveMap.put("メガトンキック",242);
    	moveMap.put("メガトンパンチ",243);
    	moveMap.put("メガドレイン",244);
    	moveMap.put("メガホーン",245);
    	moveMap.put("メタルクロー",246);
    	moveMap.put("メロメロ",247);
    	moveMap.put("ヨガのポーズ",248);
    	moveMap.put("リフレクター",249);
    	moveMap.put("ロケットずつき",250);
    	moveMap.put("ロックオン",251);
    }

	/* ソート順を返すメソッド
	 *   引数　：技名（String）
	 *   戻り値：ソート順（int）
	 *   例外　：無し
	 */
    public int getSortOrder(String moveName) {
    	Integer moveSortOrder = moveMap.get(moveName);
    	if (moveSortOrder == null) {
    		moveSortOrder = 65535;
    	}
    	return moveSortOrder;
    }

	/* compareメソッド
	 */
    @Override
    public int compare(String o1, String o2) {
        return getSortOrder(o1) - getSortOrder(o2);
    }

}
